<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//it_IT

$LANG=array();


$LANG['backup'][0]="Dump SQL"; 
$LANG['backup'][1]="Dump XML"; 
$LANG['backup'][11]="Dimensione"; 
$LANG['backup'][13]="Visualizza/Scarica"; 
$LANG['backup'][16]="Sei sicuro di voler ripristinare il database dal file di backup:"; 
$LANG['backup'][17]="Sei sicuro di voler eliminare questo file:"; 
$LANG['backup'][18]="Backup del database"; 
$LANG['backup'][19]="adesso"; 
$LANG['backup'][21]="Il file esiste già"; 
$LANG['backup'][22]="Impossibile trovare il byte"; 
$LANG['backup'][23]="Errore MySQL iniziando da"; 
$LANG['backup'][24]="Reindirizzamento automatico, oppure fai clic qui"; 

$LANG['bookmark'][1]="segnalibro"; 
$LANG['bookmark'][2]="Caricamento parziale del segnalibro."; 
$LANG['bookmark'][3]="Non hai segnalibri memorizzati."; 
$LANG['bookmark'][4]="Nuovo segnalibro"; 
$LANG['bookmark'][5]="Segnalibri pubblici"; 
$LANG['bookmark'][6]="Vista predefinita"; 

$LANG['buttons'][0]="Cerca"; 
$LANG['buttons'][2]="Invia"; 
$LANG['buttons'][3]="Associa"; 
$LANG['buttons'][4]="Installa"; 
$LANG['buttons'][5]="Disinstalla"; 
$LANG['buttons'][6]="Elimina"; 
$LANG['buttons'][7]="Aggiorna"; 
$LANG['buttons'][8]="Aggiungi"; 
$LANG['buttons'][9]="Connetti"; 
$LANG['buttons'][10]="Disconnetti"; 
$LANG['buttons'][11]="Successivo"; 
$LANG['buttons'][12]="Precedente"; 
$LANG['buttons'][13]="Indietro"; 
$LANG['buttons'][14]="Cambia"; 
$LANG['buttons'][15]="Agenda"; 
$LANG['buttons'][16]="Ripristina"; 
$LANG['buttons'][17]="Inverti selezione"; 
$LANG['buttons'][18]="Seleziona tutto"; 
$LANG['buttons'][19]="Deseleziona tutto"; 
$LANG['buttons'][20]="Sposta"; 
$LANG['buttons'][21]="Ripristina"; 
$LANG['buttons'][22]="Elimina"; 
$LANG['buttons'][23]="Mostra"; 
$LANG['buttons'][24]="Su"; 
$LANG['buttons'][25]="Giù"; 
$LANG['buttons'][27]="Esporta pagina in PDF"; 
$LANG['buttons'][28]="Esporta pagina in SLK"; 
$LANG['buttons'][29]="Esporta tutto in PDF"; 
$LANG['buttons'][30]="Esporta tutto in SLK"; 
$LANG['buttons'][31]="Esporta"; 
$LANG['buttons'][32]="Fine"; 
$LANG['buttons'][33]="Inizio"; 
$LANG['buttons'][34]="Annulla"; 
$LANG['buttons'][37]="Importa"; 
$LANG['buttons'][38]="Sblocca"; 
$LANG['buttons'][39]="Sostituisci"; 
$LANG['buttons'][40]="Mostra tutto"; 
$LANG['buttons'][41]="Attiva"; 
$LANG['buttons'][42]="Disattiva"; 
$LANG['buttons'][43]="Naviga"; 
$LANG['buttons'][44]="Esporta pagina in CSV"; 
$LANG['buttons'][45]="Esporta tutto in CSV"; 
$LANG['buttons'][46]="Prima"; 
$LANG['buttons'][47]="Dopo"; 
$LANG['buttons'][48]="Trasferisci"; 
$LANG['buttons'][49]="Mantieni"; 
$LANG['buttons'][50]="Test"; 
$LANG['buttons'][51]="Salva"; 
$LANG['buttons'][52]="Carica"; 
$LANG['buttons'][53]="Pulisci"; 
$LANG['buttons'][55]="Primo"; 
$LANG['buttons'][56]="Ultimo"; 
$LANG['buttons'][57]="Esegui"; 
$LANG['buttons'][58]="Aggiorna"; 
$LANG['buttons'][59]="Dissocia"; 

$LANG['calendar'][0]="AAAA-MM-GG"; 
$LANG['calendar'][1]="GG-MM-AAAA"; 
$LANG['calendar'][2]="MM-GG-AAAA"; 

$LANG['calendarD'][0]="D"; 
$LANG['calendarD'][1]="L"; 
$LANG['calendarD'][2]="Ma"; 
$LANG['calendarD'][3]="Me"; 
$LANG['calendarD'][4]="G"; 
$LANG['calendarD'][5]="V"; 
$LANG['calendarD'][6]="S"; 

$LANG['calendarDay'][0]="Domenica"; 
$LANG['calendarDay'][1]="Lunedì"; 
$LANG['calendarDay'][2]="Martedì"; 
$LANG['calendarDay'][3]="Mercoledì"; 
$LANG['calendarDay'][4]="Giovedì"; 
$LANG['calendarDay'][5]="Venerdì"; 
$LANG['calendarDay'][6]="Sabato"; 

$LANG['calendarM'][0]="Gennaio"; 
$LANG['calendarM'][1]="Febbraio"; 
$LANG['calendarM'][2]="Marzo"; 
$LANG['calendarM'][3]="Aprile"; 
$LANG['calendarM'][4]="Maggio"; 
$LANG['calendarM'][5]="Giugno"; 
$LANG['calendarM'][6]="Luglio"; 
$LANG['calendarM'][7]="Agosto"; 
$LANG['calendarM'][8]="Settembre"; 
$LANG['calendarM'][9]="Ottobre"; 
$LANG['calendarM'][10]="Novembre"; 
$LANG['calendarM'][11]="Dicembre"; 

$LANG['cartridges'][0]="Cartuccia"; 
$LANG['cartridges'][7]="Nessuna cartuccia trovata"; 
$LANG['cartridges'][9]="Nessuna cartuccia"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Getto di inchiostro"; 
$LANG['cartridges'][12]="Tipo cartuccia"; 
$LANG['cartridges'][13]="Nuove"; 
$LANG['cartridges'][14]="Usata/e"; 
$LANG['cartridges'][15]="Esauste"; 
$LANG['cartridges'][16]="Cartucce"; 
$LANG['cartridges'][20]="Nuova"; 
$LANG['cartridges'][21]="In uso"; 
$LANG['cartridges'][22]="Esausta"; 
$LANG['cartridges'][24]="Data acquisto"; 
$LANG['cartridges'][27]="Su"; 
$LANG['cartridges'][29]="Rimuovi"; 
$LANG['cartridges'][32]="Stampanti compatibili"; 
$LANG['cartridges'][33]="Cartucce esauste"; 
$LANG['cartridges'][34]="Non ci sono cartucce utilizzabili"; 
$LANG['cartridges'][35]="Cartucce esauste"; 
$LANG['cartridges'][37]="Nastro"; 
$LANG['cartridges'][39]="Pagine stampate"; 
$LANG['cartridges'][40]="Tempo medio di magazzino"; 
$LANG['cartridges'][41]="Tempo medio di uso"; 
$LANG['cartridges'][42]="Media di pagine stampate"; 

$LANG['central'][2]="Ultimi"; 
$LANG['central'][4]="Nessun evento"; 
$LANG['central'][5]="Pagina principale"; 
$LANG['central'][6]="Uscita"; 
$LANG['central'][7]="Aiuto"; 
$LANG['central'][8]="Inserimenti"; 
$LANG['central'][9]="Le tue chiamate in corso"; 
$LANG['central'][10]="Nuove chiamate"; 
$LANG['central'][12]="Vista personale"; 
$LANG['central'][13]="Vista generale"; 
$LANG['central'][14]="Vista gruppo"; 
$LANG['central'][18]="Le tue chiamate da chiudere"; 
$LANG['central'][19]="Le tue chiamate da convalidate"; 

$LANG['choice'][0]="No"; 
$LANG['choice'][1]="Sì"; 

$LANG['common'][0]="Senza nome"; 
$LANG['common'][1]="Elemento"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Mostra gli elementi cancellati"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="Produttore"; 
$LANG['common'][6]="Nome modello"; 
$LANG['common'][7]="Scegli un modello"; 
$LANG['common'][8]="Gestione modelli..."; 
$LANG['common'][9]="Aggiungi un modello..."; 
$LANG['common'][10]="Responsabile tecnico"; 
$LANG['common'][11]="Vista ridotta"; 
$LANG['common'][12]="Configurazione"; 
$LANG['common'][13]="Modello"; 
$LANG['common'][14]="Modelli"; 
$LANG['common'][15]="Posizione"; 
$LANG['common'][16]="Nome"; 
$LANG['common'][17]="Tipo"; 
$LANG['common'][18]="Contatto"; 
$LANG['common'][19]="Numero di serie (S/N)"; 
$LANG['common'][20]="Matricola inventario"; 
$LANG['common'][21]="Telefono"; 
$LANG['common'][22]="Modello"; 
$LANG['common'][23]="Operazione completata con successo"; 
$LANG['common'][24]="Nessun elemento selezionato o richiesta male impostata"; 
$LANG['common'][25]="Commenti"; 
$LANG['common'][26]="Ultima modifica"; 
$LANG['common'][27]="Data"; 
$LANG['common'][28]="Eliminato"; 
$LANG['common'][29]="Plugin"; 
$LANG['common'][30]="Nuovo elemento"; 
$LANG['common'][31]="Modello vuoto"; 
$LANG['common'][32]="Caratteristiche"; 
$LANG['common'][33]="Totale"; 
$LANG['common'][34]="Utente"; 
$LANG['common'][35]="Gruppo"; 
$LANG['common'][36]="Categoria"; 
$LANG['common'][37]="Autore"; 
$LANG['common'][38]="Rendi non globale"; 
$LANG['common'][39]="Duplica questo elemento tante volte quante le connessioni"; 
$LANG['common'][40]="Vuoi veramente rendere non globale questo elemento?"; 
$LANG['common'][41]="Avvisi per e-mail"; 
$LANG['common'][42]="Cellulare"; 
$LANG['common'][43]="Nome"; 
$LANG['common'][44]="Valore predefinito"; 
$LANG['common'][45]="MB massimo"; 
$LANG['common'][46]="Vcard"; 
$LANG['common'][47]="Avanzamento"; 
$LANG['common'][48]="Cognome"; 
$LANG['common'][49]="Nessuno"; 
$LANG['common'][50]="Confermi la definitiva cancellazione?"; 
$LANG['common'][51]="Nome completo"; 
$LANG['common'][52]="Server"; 
$LANG['common'][53]="Lista"; 
$LANG['common'][54]="Elemento non trovato"; 
$LANG['common'][55]="Sei sicuro di voler cancellare questo elemento?"; 
$LANG['common'][56]="Interfaccia standard"; 
$LANG['common'][57]="Titolo"; 
$LANG['common'][58]="Valore massimo"; 
$LANG['common'][59]="Globale"; 
$LANG['common'][60]="Attivo"; 
$LANG['common'][61]="Errore sconosciuto"; 
$LANG['common'][62]="Altro"; 
$LANG['common'][63]="Errore"; 
$LANG['common'][64]="Supervisore"; 
$LANG['common'][65]="Interfaccia"; 
$LANG['common'][66]="Tutti"; 
$LANG['common'][67]="Altri"; 
$LANG['common'][68]="Orizzontale"; 
$LANG['common'][69]="Verticale"; 
$LANG['common'][70]="Elemento aggiunto con successo"; 
$LANG['common'][71]="Elemento modificato con successo"; 
$LANG['common'][72]="Elemento cancellato con successo"; 
$LANG['common'][73]="Elemento eliminato con successo"; 
$LANG['common'][74]="Elemento ripristinato con successo"; 
$LANG['common'][75]="Non hai i diritti per rendere l'elemento ricorsivo in questa entità"; 
$LANG['common'][76]="Pubblico"; 
$LANG['common'][77]="Privato"; 
$LANG['common'][78]="Rendi pubblico"; 
$LANG['common'][79]="Rendi privato"; 
$LANG['common'][80]="In fase di caricamento..."; 
$LANG['common'][81]="Non mostrare gli elementi cancellati"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="Non hai diritti sufficienti per eseguire questa azione."; 
$LANG['common'][84]="La presenza di elementi collegati non permette la modifica di questo attributo"; 
$LANG['common'][85]="Cambia la visibilità nelle entità figlio"; 
$LANG['common'][86]="Non sei autorizzato a cambiare il flag di visibilità per le entità figlio."; 
$LANG['common'][87]="Nuova scheda"; 
$LANG['common'][88]="Personale"; 
$LANG['common'][89]="Non installato"; 
$LANG['common'][90]="Oggetto"; 
$LANG['common'][91]="Questo elemento è dipendente da un altro. Non è possibile modificare questo attributo poichè è ereditato."; 
$LANG['common'][92]="Contatto"; 
$LANG['common'][93]="Nuovo titolo figlio"; 

$LANG['computers'][0]="Volume"; 
$LANG['computers'][1]="Percentuale libera"; 
$LANG['computers'][2]="Spazio libero"; 
$LANG['computers'][3]="Spazio totale"; 
$LANG['computers'][4]="File System"; 
$LANG['computers'][5]="Percorso"; 
$LANG['computers'][6]="Partizione"; 
$LANG['computers'][7]="Aggiungi un volume"; 
$LANG['computers'][8]="Volumi"; 
$LANG['computers'][9]="Sistema Operativo (SO)"; 
$LANG['computers'][10]="Numero seriale SO"; 
$LANG['computers'][11]="ID prodotto SO"; 
$LANG['computers'][14]="Inserito"; 
$LANG['computers'][23]="Tipo RAM"; 
$LANG['computers'][24]="Quantità RAM"; 
$LANG['computers'][25]="Dimensione dell'hard disk"; 
$LANG['computers'][36]="Tipo di hard disk"; 
$LANG['computers'][37]="Nessuno schermo collegato"; 
$LANG['computers'][38]="Nessuna stampante collegata"; 
$LANG['computers'][39]="Stampanti"; 
$LANG['computers'][40]="Schermi"; 
$LANG['computers'][46]="Periferiche"; 
$LANG['computers'][47]="Nessuna periferica collegata"; 
$LANG['computers'][48]="Posizione variata. Le periferiche collegate sono state spostate nella nuova posizione."; 
$LANG['computers'][49]="Contatto aggiornato. I dispositivi collegati sono stati aggiornati con il nuovo contatto."; 
$LANG['computers'][50]="Utente o gruppo variato. I dispositivi collegati sono stati aggiornati al nuovo utente o gruppo."; 
$LANG['computers'][51]="Provenienza aggiornamenti"; 
$LANG['computers'][52]="Versione SO"; 
$LANG['computers'][53]="Service Pack"; 
$LANG['computers'][54]="Nessun telefono collegato"; 
$LANG['computers'][55]="Telefoni"; 
$LANG['computers'][56]="Stato variato. I dispositivi collegati sono stati aggiornati allo stato del computer."; 

$LANG['connect'][0]="Collegamenti diretti"; 
$LANG['connect'][1]="Non connesso."; 
$LANG['connect'][15]="Aggiorna automaticamente i seguenti oggetti"; 
$LANG['connect'][16]="Attenzione!! I seguenti oggetti dei due hardware non corrispondono"; 

$LANG['consumables'][0]="Materiale di consumo"; 
$LANG['consumables'][1]="In magazzino"; 
$LANG['consumables'][2]="Codice"; 
$LANG['consumables'][7]="Nessun materiale di consumo trovato"; 
$LANG['consumables'][9]="Nessun materiale di consumo"; 
$LANG['consumables'][12]="Tipo materiale di consumo"; 
$LANG['consumables'][13]="Nuovo/i"; 
$LANG['consumables'][15]="Usato/i"; 
$LANG['consumables'][16]="Materiali di consumo"; 
$LANG['consumables'][20]="Nuovo"; 
$LANG['consumables'][22]="In uso"; 
$LANG['consumables'][23]="Stato"; 
$LANG['consumables'][26]="Data di consegna"; 
$LANG['consumables'][32]="Consegnare"; 
$LANG['consumables'][35]="Materiali di consumo usati"; 
$LANG['consumables'][36]="Posizione in magazzino"; 
$LANG['consumables'][37]="Rimetti in magazzino"; 
$LANG['consumables'][38]="Soglia di allerta"; 

$LANG['contract'][0]="Contratto scaduto dal"; 
$LANG['contract'][1]="Contratto in preavviso dal"; 

$LANG['crontask'][0]="Procedure pianificate"; 
$LANG['crontask'][1]="Sincronizza le risorse da OCS-NG"; 
$LANG['crontask'][2]="Invio avvisi cartucce"; 
$LANG['crontask'][3]="Invio avvisi materiali di consumo"; 
$LANG['crontask'][4]="Invio avvisi in caso di scadenza delle licenze"; 
$LANG['crontask'][5]="Invio avvisi contratti"; 
$LANG['crontask'][6]="Invio avvisi informazioni contabili"; 
$LANG['crontask'][7]="Pulizia dei file di log"; 
$LANG['crontask'][8]="Ottimizzazione del database"; 
$LANG['crontask'][9]="Scarica e-mail (destinatari e-mail)"; 
$LANG['crontask'][10]="Controllo replica MySQL"; 
$LANG['crontask'][11]="Controllo della presenza di aggiornamenti"; 
$LANG['crontask'][12]="Cancellazione delle sessioni scadute"; 
$LANG['crontask'][13]="Cancellazione dei grafici creati"; 
$LANG['crontask'][14]="Chiusura automatica delle chiamate"; 
$LANG['crontask'][15]="Chiamate non risolte"; 
$LANG['crontask'][31]="Disabilitato"; 
$LANG['crontask'][32]="Pianificato"; 
$LANG['crontask'][33]="In esecuzione"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Modo esecuzione"; 
$LANG['crontask'][37]="Frequenza esecuzione"; 
$LANG['crontask'][38]="Durata esecuzione"; 
$LANG['crontask'][39]="Numero di e-mail da scaricare"; 
$LANG['crontask'][40]="Ultima esecuzione"; 
$LANG['crontask'][41]="Prossima esecuzione"; 
$LANG['crontask'][42]="Appena possibile"; 
$LANG['crontask'][43]="Nessun incarico in attesa"; 
$LANG['crontask'][44]="Incarico svolto, parzialmente risolutivo"; 
$LANG['crontask'][45]="Incarico svolto, risolutivo"; 
$LANG['crontask'][46]="Incarico svolto, nessuna soluzione"; 
$LANG['crontask'][47]="Elenco ultime esecuzioni"; 
$LANG['crontask'][48]="Inizio"; 
$LANG['crontask'][50]="Numero esecuzioni"; 
$LANG['crontask'][51]="Durata minima"; 
$LANG['crontask'][52]="Durata massima"; 
$LANG['crontask'][53]="Durata media"; 
$LANG['crontask'][55]="Numero minimo"; 
$LANG['crontask'][56]="Numero massimo"; 
$LANG['crontask'][57]="Numero medio"; 
$LANG['crontask'][58]="Numero totale"; 
$LANG['crontask'][59]="Velocità media"; 
$LANG['crontask'][60]="Systema bloccato"; 
$LANG['crontask'][61]="Disabilita plugin"; 
$LANG['crontask'][62]="Elementi"; 

$LANG['devices'][0]="Aggiungi nuovo componente"; 
$LANG['devices'][1]="Disco fisso"; 
$LANG['devices'][2]="Scheda grafica"; 
$LANG['devices'][3]="Scheda di rete"; 
$LANG['devices'][4]="Processore"; 
$LANG['devices'][5]="Scheda madre"; 
$LANG['devices'][6]="Memoria RAM"; 
$LANG['devices'][7]="Scheda audio"; 
$LANG['devices'][19]="Lettori"; 
$LANG['devices'][20]="Controller"; 
$LANG['devices'][21]="Componente generico"; 
$LANG['devices'][22]="Case"; 
$LANG['devices'][23]="Alimentatore"; 
$LANG['devices'][24]="Predefinita"; 
$LANG['devices'][25]="Aggiungi componente"; 
$LANG['devices'][26]="Elimina componente"; 

$LANG['device_case'][0]="Formato"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Scrittura"; 
$LANG['device_drive'][1]="Velocità"; 

$LANG['device_hdd'][0]="Velocità (rpm)"; 
$LANG['device_hdd'][1]="Cache (MB)"; 
$LANG['device_hdd'][4]="Capacità (MB)"; 

$LANG['device_iface'][0]="Velocità"; 
$LANG['device_iface'][2]="Indirizzo MAC"; 

$LANG['device_moboard'][0]="Chipset"; 

$LANG['device_power'][0]="Potenza"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frequenza (MHz)"; 
$LANG['device_ram'][2]="Capacità (MB)"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="File"; 
$LANG['document'][3]="Categoria"; 
$LANG['document'][4]="Formato MIME"; 
$LANG['document'][7]="Tipo documento"; 
$LANG['document'][9]="Estensione"; 
$LANG['document'][10]="Icona"; 
$LANG['document'][11]="Scaricabile"; 
$LANG['document'][15]="Scarica"; 
$LANG['document'][16]="Aggiungi documento"; 
$LANG['document'][18]="Documento"; 
$LANG['document'][19]="Elementi associati"; 
$LANG['document'][21]="Documenti associati"; 
$LANG['document'][22]="File corrente"; 
$LANG['document'][23]="Il file è troppo grande per essere caricato."; 
$LANG['document'][24]="Cancellato con successo il file"; 
$LANG['document'][25]="Impossibile cancellare il file"; 
$LANG['document'][26]="File valido. Caricato con successo."; 
$LANG['document'][27]="Potenziale abuso del servizio di caricamento o file troppo grande. Spostamento del file temporaneo fallito."; 
$LANG['document'][28]="Nessun file specificato."; 
$LANG['document'][29]="Impossibile creare la directory"; 
$LANG['document'][30]="Verifica possesso di diritti sufficienti."; 
$LANG['document'][31]="La directory per documenti non esiste"; 
$LANG['document'][32]="Tipo di file non consentito"; 
$LANG['document'][33]="Indirizzo Web"; 
$LANG['document'][34]="Creazione della directory"; 
$LANG['document'][35]="La directory di upload non esiste"; 
$LANG['document'][36]="Utilizza file caricato con FTP"; 
$LANG['document'][37]="Nessun file disponibile"; 
$LANG['document'][38]="File non trovato"; 
$LANG['document'][39]="Documento spostato con successo"; 
$LANG['document'][40]="Impossibile spostare il file"; 
$LANG['document'][41]="Documento copiato con successo"; 
$LANG['document'][42]="Inserito da"; 
$LANG['document'][43]="File sconosciuto"; 
$LANG['document'][44]="Nome file non valido"; 
$LANG['document'][45]="Accesso non autorizzato"; 
$LANG['document'][46]="Impossibile caricare il file (troppo grande)"; 
$LANG['document'][48]="Un documento con questo file è già disponibile"; 
$LANG['document'][49]="File modificato (checksum errato)"; 
$LANG['document'][50]="Allegati"; 

$LANG['entity'][0]="Entità"; 
$LANG['entity'][2]="Entità radice"; 
$LANG['entity'][3]="Associa ad un'entità"; 
$LANG['entity'][5]="Assegnazione automatica dei dispositivi"; 
$LANG['entity'][6]="Assegnazione automatica degli utenti"; 
$LANG['entity'][7]="ramificazione"; 
$LANG['entity'][8]="Per entità"; 
$LANG['entity'][9]="Sotto-entità"; 
$LANG['entity'][10]="Seleziona l'entità desiderata"; 
$LANG['entity'][11]="mostra entità e sotto-entità"; 
$LANG['entity'][12]="Informazioni rappresentanti l'entità LDAP (DN)"; 
$LANG['entity'][13]="TAG identificativo dell'entità"; 
$LANG['entity'][14]="Informazioni avanzate"; 
$LANG['entity'][15]="Directory associata all'entità"; 
$LANG['entity'][16]="Filtro di ricerca (se necessario)"; 
$LANG['entity'][17]="Configurazione per la chiusura automatica"; 
$LANG['entity'][18]="Chiusura automatica delle chiamate risolte dopo"; 

$LANG['event'][0]="Elemento (ID)"; 
$LANG['event'][2]="Servizio"; 
$LANG['event'][3]="Livello"; 
$LANG['event'][4]="Evento"; 
$LANG['event'][18]="Campo"; 
$LANG['event'][19]="Variazione"; 
$LANG['event'][20]="Nessuna operazione recente"; 

$LANG['financial'][1]="Contratti"; 
$LANG['financial'][2]="Perpetuo"; 
$LANG['financial'][3]="Informazioni contabili"; 
$LANG['financial'][4]="Numero"; 
$LANG['financial'][5]="Costo"; 
$LANG['financial'][6]="Tipo contratto"; 
$LANG['financial'][8]="Durata"; 
$LANG['financial'][9]="anni"; 
$LANG['financial'][10]="Preavviso"; 
$LANG['financial'][11]="Cadenza fatturazione"; 
$LANG['financial'][13]="Protocollo"; 
$LANG['financial'][14]="Data di acquisto"; 
$LANG['financial'][15]="Durata garanzia"; 
$LANG['financial'][16]="Informazioni garanzia"; 
$LANG['financial'][18]="Numero ordine"; 
$LANG['financial'][19]="Bolla di consegna"; 
$LANG['financial'][20]="Matricola inventario"; 
$LANG['financial'][21]="Importo"; 
$LANG['financial'][22]="Tipo ammortamento"; 
$LANG['financial'][23]="Durata ammortamento"; 
$LANG['financial'][24]="Aggiungi contatto..."; 
$LANG['financial'][25]="Aggiungi azienda..."; 
$LANG['financial'][26]="Azienda"; 
$LANG['financial'][30]="Fax"; 
$LANG['financial'][33]="Aggiungi contatto"; 
$LANG['financial'][36]="Aggiungi contratto"; 
$LANG['financial'][42]="Commerciale"; 
$LANG['financial'][43]="Tecnico"; 
$LANG['financial'][44]="Indirizzo"; 
$LANG['financial'][45]="Sito Web"; 
$LANG['financial'][46]="Contatti associati"; 
$LANG['financial'][47]="Lineare"; 
$LANG['financial'][48]="Decrescente"; 
$LANG['financial'][50]="Prestito"; 
$LANG['financial'][51]="Affitto"; 
$LANG['financial'][52]="Leasing"; 
$LANG['financial'][53]="Assicurazione"; 
$LANG['financial'][54]="Manutenzione hardware"; 
$LANG['financial'][55]="Manutenzione software"; 
$LANG['financial'][56]="A prestazione"; 
$LANG['financial'][57]="mesi"; 
$LANG['financial'][59]="Orario di intervento"; 
$LANG['financial'][60]="durante la settimana"; 
$LANG['financial'][61]="sabato"; 
$LANG['financial'][62]="Domenica e festivi"; 
$LANG['financial'][65]="Aziende associate"; 
$LANG['financial'][66]="Contratti associati"; 
$LANG['financial'][68]="Attiva informazioni contabili"; 
$LANG['financial'][69]="Periodo contratto"; 
$LANG['financial'][76]="Data collaudo"; 
$LANG['financial'][77]="Coefficiente ammortamento"; 
$LANG['financial'][78]="Importo estensione garanzia"; 
$LANG['financial'][79]="Rapporto"; 
$LANG['financial'][80]="Scadenza garanzia"; 
$LANG['financial'][81]="Valore netto contabile"; 
$LANG['financial'][82]="Numero fattura"; 
$LANG['financial'][83]="Numero massimo dei dispositivi"; 
$LANG['financial'][84]="Per questo tipo, le informazioni contabili sono solo un modello per gli elementi che verranno inseriti."; 
$LANG['financial'][85]="Elemento richiesto non trovato"; 
$LANG['financial'][86]="Scadenza del contratto"; 
$LANG['financial'][87]="Centro dei costi"; 
$LANG['financial'][88]="Scadenza:"; 
$LANG['financial'][89]="TCO (valore + costo interventi)"; 
$LANG['financial'][90]="TCO mensile"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="VNC"; 
$LANG['financial'][93]="Contratti scaduti negli ultimi 30 giorni"; 
$LANG['financial'][94]="Contratti in scadenza nei prossimi 7 giorni"; 
$LANG['financial'][95]="Contratti in scadenza nei prossimi 30 giorni"; 
$LANG['financial'][96]="Contratti in preavviso nei prossimi 7 giorni"; 
$LANG['financial'][97]="Contratti in preavviso nei prossimi 30 giorni"; 
$LANG['financial'][98]="Data fine"; 
$LANG['financial'][99]="Data fine + preavviso"; 
$LANG['financial'][100]="CAP"; 
$LANG['financial'][101]="Città"; 
$LANG['financial'][102]="Stato"; 
$LANG['financial'][103]="Nazione"; 
$LANG['financial'][104]="Elementi associati"; 
$LANG['financial'][105]="Tacito"; 
$LANG['financial'][106]="Esplicito"; 
$LANG['financial'][107]="Rinnovo"; 
$LANG['financial'][108]="Totale uscite per il centro dei costi"; 
$LANG['financial'][109]="Totale residui per il centro dei costi"; 
$LANG['financial'][110]="Bilanci"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="ore"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="Matrice di calcolo per la priorità"; 
$LANG['help'][2]="Maggiore"; 
$LANG['help'][3]="Molto alta"; 
$LANG['help'][4]="Alta"; 
$LANG['help'][5]="Media"; 
$LANG['help'][6]="Bassa"; 
$LANG['help'][7]="Molto bassa"; 
$LANG['help'][8]="Informami, tramite e-mail, delle azioni compiute"; 
$LANG['help'][11]="La mia e-mail"; 
$LANG['help'][14]="Invia la chiamata"; 
$LANG['help'][16]="Se vuoi essere informato delle azioni compiute, inserisci la tua e-mail."; 
$LANG['help'][18]="La chiamata è stata inviata correttamente."; 
$LANG['help'][19]="Grazie per aver usato questo sistema di assistenza."; 
$LANG['help'][22]="Cerca l'ID del tuo computer"; 
$LANG['help'][23]="Inserisci i primi caratteri (del nome, del dispositivo o del seriale)"; 
$LANG['help'][24]="Chiamata relativa a"; 
$LANG['help'][25]="Computer"; 
$LANG['help'][26]="Apparato di rete"; 
$LANG['help'][27]="Stampante"; 
$LANG['help'][28]="Schermo"; 
$LANG['help'][29]="Periferica"; 
$LANG['help'][30]="Generico"; 
$LANG['help'][31]="Software"; 
$LANG['help'][35]="Telefono"; 
$LANG['help'][40]="Manca un titolo per la chiamata, inseriscilo."; 
$LANG['help'][41]="Manca una categoria per la chiamata, inseriscila."; 
$LANG['help'][42]="Molto alta"; 
$LANG['help'][43]="Alta"; 
$LANG['help'][44]="Media"; 
$LANG['help'][45]="Bassa"; 
$LANG['help'][46]="Molto bassa"; 
$LANG['help'][47]="Molto alta"; 
$LANG['help'][48]="Alta"; 
$LANG['help'][49]="Media"; 
$LANG['help'][50]="Bassa"; 
$LANG['help'][51]="Molto bassa"; 

$LANG['install'][0]="Installa od aggiorna GLPI"; 
$LANG['install'][1]="Scegli 'Installa' per una nuova installazione di GLPI (i dati inseriti saranno quelli predefiniti)"; 
$LANG['install'][2]="Scegli 'Aggiorna' per aggiornare una precedente versione di GLPI"; 
$LANG['install'][3]="Installa"; 
$LANG['install'][4]="Aggiorna"; 
$LANG['install'][5]="Verifica della compatibilità del tuo ambiente per l'esecuzione di GLPI"; 
$LANG['install'][6]="Verifica effettuata"; 
$LANG['install'][7]="Risultato"; 
$LANG['install'][8]="Verifica dell'interprete PHP"; 
$LANG['install'][9]="Devi installare almeno la versione 5 di PHP."; 
$LANG['install'][10]="GLPI non è compatibile con la direttiva zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="La versione di PHP è superiore al minimo richiesto - Perfetto!"; 
$LANG['install'][12]="Verifica delle sessioni"; 
$LANG['install'][13]="Il tuo interprete PHP non ha il supporto per le sessioni!"; 
$LANG['install'][14]="Il supporto delle sessioni è disponibile - Perfetto!"; 
$LANG['install'][15]="Verifica che il supporto delle sessioni sia attivato nel tuo php.ini"; 
$LANG['install'][16]="Verifica della scrittura dei file di dump"; 
$LANG['install'][17]="Il file non può essere creato."; 
$LANG['install'][18]="Sono inoltre disponibili traduzioni non ufficiali"; 
$LANG['install'][19]="Il file può essere creato ma non eliminato."; 
$LANG['install'][20]="File e directory sono stati creati e cancellati - perfetto!"; 
$LANG['install'][21]="Verifica della scrittura dei file dei documenti"; 
$LANG['install'][22]="Il file è stato creato creato - perfetto!"; 
$LANG['install'][23]="Verifica della scrittura dei file di configurazione"; 
$LANG['install'][24]="Inizializzazione del database"; 
$LANG['install'][25]="Continuare?"; 
$LANG['install'][26]="Continua"; 
$LANG['install'][27]="Riprova"; 
$LANG['install'][28]="Impostazioni di connessione al database"; 
$LANG['install'][29]="Parametri di connessione al database"; 
$LANG['install'][30]="MySQL-Server"; 
$LANG['install'][31]="MySQL-Utente"; 
$LANG['install'][32]="MySQL-Password"; 
$LANG['install'][34]="Verifica della connessione al database"; 
$LANG['install'][35]="Impossibile connettersi al database"; 
$LANG['install'][36]="Il server ha risposto"; 
$LANG['install'][37]="Il campo server e/o utente è vuoto"; 
$LANG['install'][38]="Per favore seleziona il database:"; 
$LANG['install'][39]="Crea un nuovo database od utilizzane uno esistente:"; 
$LANG['install'][40]="Seleziona il database che si vuole aggiornare:"; 
$LANG['install'][41]="Impossible usare il database:"; 
$LANG['install'][43]="Database inizializzato"; 
$LANG['install'][47]="Impossibile scrivere il file di configurazione del database"; 
$LANG['install'][48]="Errore nella creazione del database!"; 
$LANG['install'][49]="Non hai selezionato un database!"; 
$LANG['install'][50]="Verifica della scrittura dei file di sessione"; 
$LANG['install'][52]="Verifica dei permessi di scrittura dei file di cron"; 
$LANG['install'][53]="Verifica della scrittura dei file di log"; 
$LANG['install'][55]="Installazione terminata"; 
$LANG['install'][57]="Gli utenti/password predefiniti sono:"; 
$LANG['install'][58]="glpi/glpi per l'account amministratore"; 
$LANG['install'][59]="tech/tech per l'account tecnico"; 
$LANG['install'][60]="normal/normal per l'account normal"; 
$LANG['install'][61]="post-only/post-only per l'account postonly"; 
$LANG['install'][62]="Puoi cancellare o modificare questi account nonchè i primi record nel database."; 
$LANG['install'][64]="Usa GLPI"; 
$LANG['install'][65]="Verifica dell'estensione magic_quotes_sybase"; 
$LANG['install'][66]="GLPI non può funzionare con l'opzione PHP magic_quotes_sybase attivata; disattivala e riprova"; 
$LANG['install'][67]="Opzione magic_quotes_sybase non attiva sul server - Perfetto!"; 
$LANG['install'][68]="Verifica dell'avvio automatico delle sessioni"; 
$LANG['install'][69]="session.auto_start è attivato. Per ulteriori informazioni fai riferimento al file .htaccess nella root directory di GLPI."; 
$LANG['install'][70]="Impossibile creare il file per la connessione al database, verificare i permessi di accesso"; 
$LANG['install'][71]="Verifica dell'estensione MySQL"; 
$LANG['install'][72]="Devi compilare PHP con l'estensione MySQL"; 
$LANG['install'][73]="La funzione mysql_query() esiste - Perfetto!"; 
$LANG['install'][74]="Verifica dell'utilizzo di Session_use_trans_sid"; 
$LANG['install'][75]="Devi disattivare l'opzione Session_use_trans_id nel tuo php.ini"; 
$LANG['install'][76]="Le sessioni funzionano (nessun problema trans_id) - Perfetto!"; 
$LANG['install'][77]="Passo"; 
$LANG['install'][81]="Inizio dell'installazione"; 
$LANG['install'][82]="Database creato"; 
$LANG['install'][85]="Le funzioni esistono - Perfetto!"; 
$LANG['install'][86]="Verifica della memoria utilizzata"; 
$LANG['install'][87]="Memoria utilizzata:"; 
$LANG['install'][88]="Un minimo di 64MB di memoria sono necessari per GLPI."; 
$LANG['install'][89]="Perfetto!"; 
$LANG['install'][90]="Prova ad aumentare il parametro memory_limit nel file di configurazione di PHP (php.ini)"; 
$LANG['install'][91]="Memoria allocata > 64M"; 
$LANG['install'][92]="Licenza"; 
$LANG['install'][93]="Ho letto e ACCETTO le condizioni della licenza"; 
$LANG['install'][94]="Ho letto e NON ACCETTO le condizioni della licenza"; 
$LANG['install'][95]="Memoria illimitata"; 
$LANG['install'][96]="Memoria illimitata"; 
$LANG['install'][97]="Verifica i permessi per la directory:"; 
$LANG['install'][99]="Verifica della scrittura dei file di cache"; 
$LANG['install'][100]="La directory non è stata creata"; 
$LANG['install'][101]="La directory è stata creata ma non può essere cancellata"; 
$LANG['install'][102]="Verifica delle funzioni json"; 
$LANG['install'][103]="GLPI non può funzionare correttamente senza le funzioni json_encode e json_decode"; 
$LANG['install'][104]="Verifica dell'estensione mbstring"; 
$LANG['install'][105]="L'estensione MBSTRING dell'interprete PHP non è installata"; 
$LANG['install'][106]="Verifica della scrittura dei file dei grafici"; 

$LANG['job'][2]="da"; 
$LANG['job'][4]="Richiesta da"; 
$LANG['job'][5]="Assegnata a"; 
$LANG['job'][6]="Tecnico"; 
$LANG['job'][7]="Incarico"; 
$LANG['job'][8]="ultimi commenti"; 
$LANG['job'][9]="Commento"; 
$LANG['job'][11]="Descrivi il problema"; 
$LANG['job'][12]="Nessun commento per questa chiamata."; 
$LANG['job'][13]="Apri una nuova chiamata"; 
$LANG['job'][15]="Risolto"; 
$LANG['job'][19]="Commenti per e-mail"; 
$LANG['job'][20]="Durata totale"; 
$LANG['job'][21]="Ore"; 
$LANG['job'][22]="Minuti"; 
$LANG['job'][29]="Aggiungi un nuovo commento"; 
$LANG['job'][30]="Aggiungi un nuovo incarico"; 
$LANG['job'][31]="Durata"; 
$LANG['job'][32]="Nessuna"; 
$LANG['job'][33]="Descrizione vuota"; 
$LANG['job'][34]="Pianifica questo incarico"; 
$LANG['job'][35]="Pianificazione"; 
$LANG['job'][37]="Sommario"; 
$LANG['job'][38]="Chiamata"; 
$LANG['job'][39]="Aggiorna il commento"; 
$LANG['job'][40]="Costo orario"; 
$LANG['job'][41]="Costo fisso"; 
$LANG['job'][42]="Costo del materiale"; 
$LANG['job'][43]="Costo totale"; 
$LANG['job'][44]="Origine delle richiesta"; 
$LANG['job'][45]="Origine del commento"; 
$LANG['job'][46]="La chiamata sarà creata nell'entità"; 
$LANG['job'][47]="Costi"; 
$LANG['job'][48]="Tipo di soluzione"; 
$LANG['job'][49]="Nuovo incarico"; 
$LANG['job'][50]="Nessun incarico per questa chiamata"; 
$LANG['job'][51]="Approva soluzione"; 
$LANG['job'][52]="Aggiorna incarico"; 
$LANG['job'][53]="Cancella incarico"; 
$LANG['job'][54]="In assenza di una risposta, la chiamata sarà automaticamente chiusa dopo"; 

$LANG['joblist'][0]="Stato"; 
$LANG['joblist'][1]="Solo le mie"; 
$LANG['joblist'][2]="Priorità"; 
$LANG['joblist'][3]="Mie e dei miei gruppi"; 
$LANG['joblist'][4]="Assegnata"; 
$LANG['joblist'][6]="Descrizione"; 
$LANG['joblist'][7]="Inserisci una nuova chiamata per questo dispositivo"; 
$LANG['joblist'][8]="Nessuna chiamata"; 
$LANG['joblist'][9]="Nuova"; 
$LANG['joblist'][10]="Chiusa (risolta)"; 
$LANG['joblist'][11]="Aperta il"; 
$LANG['joblist'][12]="Chiusa il"; 
$LANG['joblist'][13]="Chiamate da evadere"; 
$LANG['joblist'][14]="Risolta il"; 
$LANG['joblist'][16]="Nessuna chiamata in corso."; 
$LANG['joblist'][17]="Chiusa (non risolta)"; 
$LANG['joblist'][18]="In lavorazione (assegnata)"; 
$LANG['joblist'][19]="In lavorazione (pianificata)"; 
$LANG['joblist'][21]="In lavorazione"; 
$LANG['joblist'][26]="In sospeso"; 
$LANG['joblist'][27]="E-mail per i commenti"; 
$LANG['joblist'][28]="Chiamate aperte su elementi associati"; 
$LANG['joblist'][29]="Priorità"; 
$LANG['joblist'][30]="Impatto"; 
$LANG['joblist'][32]="Risolta"; 
$LANG['joblist'][33]="Chiuso"; 
$LANG['joblist'][34]="Non risolta"; 
$LANG['joblist'][35]="Non chiusa"; 
$LANG['joblist'][36]="Valore dello stato nel database"; 

$LANG['jobresolution'][1]="Soluzione"; 
$LANG['jobresolution'][3]="Soluzione approvata"; 
$LANG['jobresolution'][4]="Soluzione respinta"; 
$LANG['jobresolution'][5]="In caso di respingimento della soluzione dovete indicare la ragione"; 

$LANG['knowbase'][1]="FAQ"; 
$LANG['knowbase'][5]="Inserisci questo documento nelle FAQ pubbliche"; 
$LANG['knowbase'][6]="Seleziona una categoria per questo documento:"; 
$LANG['knowbase'][7]="Elimina questo documento dalle FAQ pubbliche"; 
$LANG['knowbase'][8]="Modifica questo documento"; 
$LANG['knowbase'][9]="Elimina questo documento"; 
$LANG['knowbase'][10]="Questo documento è nelle FAQ pubbliche"; 
$LANG['knowbase'][11]="Questo documento non è nelle FAQ pubbliche"; 
$LANG['knowbase'][12]="Radice"; 
$LANG['knowbase'][13]="Categoria"; 
$LANG['knowbase'][14]="Oggetto"; 
$LANG['knowbase'][15]="Contenuto"; 
$LANG['knowbase'][24]="Accesso alle domande poste frequentemente (FAQ)"; 
$LANG['knowbase'][26]="Visualizzato"; 
$LANG['knowbase'][27]="In data"; 
$LANG['knowbase'][29]="Nuovi inserimenti"; 
$LANG['knowbase'][30]="Domande più frequenti"; 

$LANG['ldap'][0]="Importazione in blocco di utenti da directory LDAP"; 
$LANG['ldap'][1]="Sincronizzazione utenti già importati"; 
$LANG['ldap'][2]="Importa nuovi utenti"; 
$LANG['ldap'][3]="Nessun utente da importare"; 
$LANG['ldap'][4]="Scelta directory LDAP"; 
$LANG['ldap'][5]="Scegli la directory LDAP da cui importare gli utenti"; 
$LANG['ldap'][6]="Impossibile contattare la directory LDAP"; 
$LANG['ldap'][7]="Nessuna directory LDAP definita in GLPI"; 
$LANG['ldap'][8]="Attenzione: la richiesta eccede i limiti LDAP. I risultati sono parziali."; 
$LANG['ldap'][9]="Verifica connessione alla directory LDAP"; 
$LANG['ldap'][12]="Sincronizzazione"; 
$LANG['ldap'][13]="nella directory LDAP"; 
$LANG['ldap'][14]="in GLPI"; 
$LANG['ldap'][15]="Sincronizza"; 
$LANG['ldap'][16]="Preconfigurazione"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="Mostra le repliche LDAP"; 
$LANG['ldap'][19]="Replica"; 
$LANG['ldap'][20]="Aggiungi replica LDAP"; 
$LANG['ldap'][21]="Server principale"; 
$LANG['ldap'][22]="Repliche"; 
$LANG['ldap'][23]="Importazione in blocco di gruppi da directory LDAP"; 
$LANG['ldap'][24]="Importa nuovi gruppi"; 
$LANG['ldap'][25]="Nessun gruppo da importare"; 
$LANG['ldap'][30]="Come dovrebbero essere gestiti gli alias LDAP"; 
$LANG['ldap'][31]="Mai dereferenziati (predefinito)"; 
$LANG['ldap'][32]="Sempre dereferenziati"; 
$LANG['ldap'][33]="Dereferenziati durante la ricerca"; 
$LANG['ldap'][34]="Dereferenziati durante la localizzazione"; 
$LANG['ldap'][35]="Importa un utente"; 
$LANG['ldap'][36]="Nessuna directory associata all'entità: ricerca impossibile"; 
$LANG['ldap'][38]="Criteri di ricerca utenti"; 
$LANG['ldap'][39]="Esperto"; 
$LANG['ldap'][40]="Semplice"; 
$LANG['ldap'][41]="Modifica"; 
$LANG['ldap'][42]="Nessuna directory selezionata"; 
$LANG['ldap'][43]="Nessun utente da sincronizzare"; 
$LANG['ldap'][44]="Server predefinito"; 
$LANG['ldap'][45]="Azione quando un utente viene eliminato dalla directory LDAP"; 
$LANG['ldap'][46]="Recupera credenziali e gruppi (dinamica)"; 
$LANG['ldap'][47]="Metti nel cestino"; 
$LANG['ldap'][48]="Cancella utente in LDAP"; 
$LANG['ldap'][49]="Visualizza gli utenti aggiunti dopo"; 
$LANG['ldap'][50]="Visualizza gli utenti aggiornati dopo"; 
$LANG['ldap'][52]="Meno di"; 
$LANG['ldap'][53]="Più di"; 
$LANG['ldap'][54]="Abilitare il filtro per data"; 
$LANG['ldap'][55]="Disabilitare il filtro per data"; 
$LANG['ldap'][56]="Settimane"; 

$LANG['links'][1]="Collegamento o nome file"; 
$LANG['links'][4]="Tipo di hardware associato"; 
$LANG['links'][6]="Etichette utilizzabili"; 
$LANG['links'][7]="Nessun collegamento associato"; 
$LANG['links'][9]="Contenuto del file"; 

$LANG['log'][1]="sistema"; 
$LANG['log'][16]="pianificazione"; 
$LANG['log'][18]="componenti"; 
$LANG['log'][20]="aggiunta elemento"; 
$LANG['log'][21]="aggiornato elemento"; 
$LANG['log'][22]="cancellato elemento"; 
$LANG['log'][23]="ripristina elemento"; 
$LANG['log'][24]="eliminato elemento"; 
$LANG['log'][26]="disconnesso elemento"; 
$LANG['log'][27]="connesso elemento"; 
$LANG['log'][28]="modifica dei componenti"; 
$LANG['log'][29]="approvazione/rifiuto della soluzione"; 
$LANG['log'][30]="associato a tipo"; 
$LANG['log'][31]="cancellato un tipo"; 
$LANG['log'][32]="aggiunto collegamento ad elemento"; 
$LANG['log'][33]="cancellato collegamento ad elemento"; 
$LANG['log'][34]="aggiunto collegamento a fornitore"; 
$LANG['log'][35]="cancellato collegamento a fornitore"; 
$LANG['log'][40]="connessione IP"; 
$LANG['log'][41]="connessione fallita"; 
$LANG['log'][42]="Prenotazione"; 
$LANG['log'][44]="Intestazione"; 
$LANG['log'][45]="Riuscita"; 
$LANG['log'][46]="Fallita"; 
$LANG['log'][48]="aggiunto utente a gruppo"; 
$LANG['log'][49]="utente cancellato dal gruppo"; 
$LANG['log'][55]="Connessioni"; 
$LANG['log'][59]="Cron"; 
$LANG['log'][60]="utilizza la gestione unitaria per questo articolo"; 
$LANG['log'][61]="aggiunto utente ad entità"; 
$LANG['log'][62]="utente cancellato dall'entità"; 
$LANG['log'][64]="modifica del campo"; 
$LANG['log'][65]="regola"; 
$LANG['log'][66]="Sicurezza"; 
$LANG['log'][67]="modifica delle note"; 
$LANG['log'][70]="aggiunta porta di rete"; 
$LANG['log'][71]="aggiunte alcune porte di rete"; 
$LANG['log'][73]="cancellata porta di rete"; 
$LANG['log'][74]="cancellate alcune porte di rete"; 
$LANG['log'][75]="spostata porta di rete"; 
$LANG['log'][77]="assegnata vlan a porta di rete"; 
$LANG['log'][78]="assegnata vlan ad alcune porte di rete"; 
$LANG['log'][79]="rimossa vlan dalla porta di rete"; 
$LANG['log'][80]="rimossa vlan da alcune porte di rete"; 
$LANG['log'][82]="aggiunta versione"; 
$LANG['log'][83]="modifica della versione"; 
$LANG['log'][84]="eliminata versione"; 
$LANG['log'][85]="aggiunta licenza"; 
$LANG['log'][86]="modifica della licenza"; 
$LANG['log'][87]="cancellata licenza"; 
$LANG['log'][88]="aggiunta di cartucce"; 
$LANG['log'][89]="aggiunta di consumabili"; 
$LANG['log'][90]="cancellata una cartuccia"; 
$LANG['log'][91]="cancellato un consumabile"; 
$LANG['log'][92]="ripristino di una cartuccia"; 
$LANG['log'][93]="ripristino di un consumabile"; 
$LANG['log'][94]="aggiornamento di una cartuccia"; 
$LANG['log'][95]="installazione di una cartuccia"; 
$LANG['log'][96]="rimozione di una cartuccia"; 
$LANG['log'][97]="consegna di un consumabile all'utente"; 
$LANG['log'][98]="aggiunta di un elemento"; 
$LANG['log'][99]="modifica di un elemento"; 
$LANG['log'][100]="cancellato un elemento"; 

$LANG['login'][0]="Ultimo accesso"; 
$LANG['login'][1]="Ripeti login"; 
$LANG['login'][2]="Directory LDAP"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Accesso negato"; 
$LANG['login'][6]="Login"; 
$LANG['login'][7]="Password"; 
$LANG['login'][8]="Campo nome utente o password vuoto"; 
$LANG['login'][9]="Non ancora autenticato"; 
$LANG['login'][10]="Autenticazione"; 
$LANG['login'][11]="Utente non abilitato"; 
$LANG['login'][12]="Nome utente o password errata"; 
$LANG['login'][13]="Il campo password è vuoto"; 
$LANG['login'][14]="Utente sconosciuto"; 
$LANG['login'][15]="Utente non trovato oppure sono stati trovati utenti multipli"; 
$LANG['login'][16]="Identificazione LDAP fallita"; 
$LANG['login'][18]="Elenco interno GLPI"; 
$LANG['login'][20]="Non hai accesso a questo applicativo perchè il tuo account è stato disattivato o rimosso"; 
$LANG['login'][21]="Verifica connessione server IMAP/POP"; 
$LANG['login'][22]="Verifica riuscita"; 
$LANG['login'][23]="Verifica fallita"; 
$LANG['login'][24]="Data ultimo accesso"; 
$LANG['login'][25]="Non hai i diritti per accedere a questo applicativo"; 
$LANG['login'][26]="Devi attivare JavaScript sul tuo browser"; 
$LANG['login'][27]="Devi abilitare i cookies per accedere a questo applicativo"; 
$LANG['login'][30]="Modifica del metodo di autenticazione"; 
$LANG['login'][31]="Autenticazione sulla directory LDAP"; 
$LANG['login'][32]="Autenticazione sul database GLPI"; 
$LANG['login'][33]="Autenticazione al server IMAP/POP"; 

$LANG['mailgate'][0]="Gateway e-mail"; 
$LANG['mailgate'][2]="Scarica ora le chiamate via e-mail"; 
$LANG['mailgate'][3]="Numero di e-mail disponibili e scaricate"; 
$LANG['mailgate'][4]="Estensione mbstring non trovata. Attenzione al set di caratteri utilizzato."; 
$LANG['mailgate'][5]="File allegato non valido"; 
$LANG['mailgate'][6]="File allegato troppo grande"; 
$LANG['mailgate'][7]="Dimensione massima di ogni messaggio ricevuto dal Gateway e-mail"; 
$LANG['mailgate'][9]="La tua e-mail non può essere elaborata.\nSe il problema persiste, contatta l'amministratore"; 
$LANG['mailgate'][10]="E-mail respinta"; 
$LANG['mailgate'][11]="Processo di importazione delle e-mail"; 
$LANG['mailgate'][12]="Impossibile collegare l'e-mail ad un'entità"; 
$LANG['mailgate'][13]="Motivo del rifiuto"; 
$LANG['mailgate'][14]="E-mail non trovata. Importazione impossibile"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="====================================================================="; 
$LANG['mailing'][4]="Intervento già effettuato"; 
$LANG['mailing'][5]="Descrizione chiamata"; 
$LANG['mailing'][10]="Nuovo commento per la chiamata"; 
$LANG['mailing'][12]="Chiamata assegnata a"; 
$LANG['mailing'][14]="Modifica categoria chiamata"; 
$LANG['mailing'][15]="Modifica priorità chiamata"; 
$LANG['mailing'][17]="Modifica dispositivo coinvolto nella chiamata"; 
$LANG['mailing'][18]="Modifica autore chiamata"; 
$LANG['mailing'][19]="Nuova prenotazione"; 
$LANG['mailing'][20]="Modifica gruppo chiamata"; 
$LANG['mailing'][21]="Modifica origine chiamata"; 
$LANG['mailing'][23]="Modifica prenotazione"; 
$LANG['mailing'][26]="Documento inserito:"; 
$LANG['mailing'][27]="Modifica stato chiamata"; 
$LANG['mailing'][29]="Prenotazione annullata"; 
$LANG['mailing'][30]="Modifica chiamata"; 
$LANG['mailing'][31]="Questo è un messaggio di test per verificare che il sistema di segnalazione funzioni"; 
$LANG['mailing'][32]="Verifica e-mail"; 
$LANG['mailing'][33]="Avviso cartucce"; 
$LANG['mailing'][35]="Soglia di allerta raggiunta per materiali di consumo:"; 
$LANG['mailing'][36]="Avviso materiali di consumo"; 
$LANG['mailing'][37]="Contratto entrato nel periodo di preavviso:"; 
$LANG['mailing'][39]="Avviso contratti"; 
$LANG['mailing'][40]="Dispositivi con garanzia scaduta:"; 
$LANG['mailing'][41]="Avviso informazioni contabili"; 
$LANG['mailing'][42]="Modifica costo orario"; 
$LANG['mailing'][43]="Modifica costo fisso"; 
$LANG['mailing'][44]="Modifica costo materiale"; 
$LANG['mailing'][45]="Modifica intestazione chiamata"; 
$LANG['mailing'][46]="Modifica descrizione chiamata"; 
$LANG['mailing'][47]="Errore durante l'invio dell'e-mail"; 
$LANG['mailing'][48]="Modifica data apertura"; 
$LANG['mailing'][49]="Modifica data chiusura"; 
$LANG['mailing'][50]="Modifica destinatario chiamata"; 
$LANG['mailing'][51]="Licenza scaduta:"; 
$LANG['mailing'][53]="Modifica soluzione"; 
$LANG['mailing'][54]="Data scadenza"; 
$LANG['mailing'][100]="Nessuna categoria definita"; 
$LANG['mailing'][101]="Commenti per e-mail abilitati"; 
$LANG['mailing'][102]="Commenti per e-mail disabilitati"; 
$LANG['mailing'][104]="Durata intervento"; 
$LANG['mailing'][105]="Non assegnato"; 
$LANG['mailing'][107]="Nessun dispositivo coinvolto"; 
$LANG['mailing'][109]="Nessun gruppo"; 
$LANG['mailing'][110]="E-mail non valida"; 
$LANG['mailing'][113]="Modelli di notifica"; 
$LANG['mailing'][114]="Corpo"; 
$LANG['mailing'][115]="Contenuto dell'e-mail"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="testo"; 
$LANG['mailing'][118]="E-mail"; 
$LANG['mailing'][119]="Occorrenza"; 
$LANG['mailing'][120]="Modalità di notifica"; 
$LANG['mailing'][121]="Destinatari"; 
$LANG['mailing'][122]="Incarichi già svolti"; 
$LANG['mailing'][123]="Chiamata risolta"; 
$LANG['mailing'][124]="Aggiungi nuova traduzione"; 
$LANG['mailing'][125]="Traduzione predefinita"; 
$LANG['mailing'][126]="Traduci modello"; 
$LANG['mailing'][127]="Chiusura della chiamata"; 
$LANG['mailing'][128]="lasciare il campo vuoto per una generazione da HTML"; 
$LANG['mailing'][129]="Cancella chiamata"; 
$LANG['mailing'][130]="Da"; 
$LANG['mailing'][131]="Destinatario"; 
$LANG['mailing'][132]="Intestazione dell'e-mail"; 
$LANG['mailing'][133]="Cancella e-mail"; 
$LANG['mailing'][134]="Aggiornamento commento"; 
$LANG['mailing'][135]="Cancellazione commento"; 
$LANG['mailing'][136]="Scadenza prenotazione"; 
$LANG['mailing'][137]="Utente del materiale"; 
$LANG['mailing'][138]="Lista delle etichette disponibili"; 
$LANG['mailing'][139]="Etichetta"; 
$LANG['mailing'][140]="Etichetta"; 
$LANG['mailing'][141]="Commenti"; 
$LANG['mailing'][142]="Incarichi"; 
$LANG['mailing'][143]="Convalida"; 
$LANG['mailing'][144]="Storico"; 
$LANG['mailing'][145]="Lista dei valori"; 
$LANG['mailing'][146]="Valore singolo"; 
$LANG['mailing'][147]="Valori accettabili"; 

$LANG['Menu'][0]="Computer"; 
$LANG['Menu'][1]="Apparati di rete"; 
$LANG['Menu'][2]="Stampanti"; 
$LANG['Menu'][3]="Schermi"; 
$LANG['Menu'][4]="Software"; 
$LANG['Menu'][5]="Chiamate"; 
$LANG['Menu'][6]="Rapporti"; 
$LANG['Menu'][11]="Preferenze"; 
$LANG['Menu'][12]="Manutenzione"; 
$LANG['Menu'][13]="Statistiche"; 
$LANG['Menu'][14]="Utenti"; 
$LANG['Menu'][15]="Amministrazione"; 
$LANG['Menu'][16]="Periferiche"; 
$LANG['Menu'][17]="Prenotazioni"; 
$LANG['Menu'][18]="Utilità"; 
$LANG['Menu'][19]="Knowledge base"; 
$LANG['Menu'][20]="FAQ"; 
$LANG['Menu'][21]="Cartucce"; 
$LANG['Menu'][22]="Rubrica"; 
$LANG['Menu'][23]="Aziende"; 
$LANG['Menu'][24]="Informazioni contabili"; 
$LANG['Menu'][25]="Contratti"; 
$LANG['Menu'][26]="Gestione"; 
$LANG['Menu'][27]="Documenti"; 
$LANG['Menu'][28]="Stato"; 
$LANG['Menu'][29]="Pianificazione"; 
$LANG['Menu'][30]="Log"; 
$LANG['Menu'][31]="Interfaccia semplificata"; 
$LANG['Menu'][32]="Materiali di consumo"; 
$LANG['Menu'][33]="OCS-NG"; 
$LANG['Menu'][34]="Telefoni"; 
$LANG['Menu'][35]="Profili"; 
$LANG['Menu'][36]="Gruppi"; 
$LANG['Menu'][37]="Entità"; 
$LANG['Menu'][38]="Inventario"; 
$LANG['Menu'][39]="Gateway"; 
$LANG['Menu'][40]="Segnalibri"; 
$LANG['Menu'][41]="Diritti"; 

$LANG['monitors'][14]="Microfono"; 
$LANG['monitors'][15]="Altoparlanti"; 
$LANG['monitors'][18]="Opzioni"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Dimensioni"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivot"; 

$LANG['networking'][4]="Porta di rete"; 
$LANG['networking'][5]="RAM (MB)"; 
$LANG['networking'][6]="Porte di rete"; 
$LANG['networking'][13]="Porte di rete trovate"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Connessa a"; 
$LANG['networking'][19]="Aggiungi porta..."; 
$LANG['networking'][21]="Numero della porta"; 
$LANG['networking'][25]="su"; 
$LANG['networking'][37]="Porte di rete trovate"; 
$LANG['networking'][44]="La porta"; 
$LANG['networking'][46]="Aggiungi porte..."; 
$LANG['networking'][47]="Da"; 
$LANG['networking'][48]="A"; 
$LANG['networking'][51]="Punto rete"; 
$LANG['networking'][55]="Associa VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Scegli un indirizzo MAC dalla lista od inseriscilo qui sotto"; 
$LANG['networking'][58]="Elimina VLAN"; 
$LANG['networking'][59]="Gateway"; 
$LANG['networking'][60]="Netmask"; 
$LANG['networking'][61]="Subnet"; 

$LANG['ocsconfig'][1]="Utente del database OCS-NG"; 
$LANG['ocsconfig'][2]="Server del database OCS-NG"; 
$LANG['ocsconfig'][3]="Password dell'utente OCS-NG"; 
$LANG['ocsconfig'][4]="Nome del database OCS-NG"; 
$LANG['ocsconfig'][5]="Opzioni di importazione"; 
$LANG['ocsconfig'][6]="Ignoralo nell'importazione OCS-NG"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Escludi i seguenti tag (usa $ come separatore, se assente include tutti)"; 
$LANG['ocsconfig'][10]="Importazione globale"; 
$LANG['ocsconfig'][11]="Non importare"; 
$LANG['ocsconfig'][12]="Importa unità"; 
$LANG['ocsconfig'][13]="Importa unità: tutto è importato 'così com'è'"; 
$LANG['ocsconfig'][14]="Importazione globale: viene importato tutto ma il materiale è gestito a livello globale (senza duplicati)"; 
$LANG['ocsconfig'][15]="Non importati: GLPI non importerà questi elementi"; 
$LANG['ocsconfig'][16]="Stato predefinito"; 
$LANG['ocsconfig'][17]="Limita l'importazione ai seguenti tag (usa $ come separatore, se assente importa tutti)"; 
$LANG['ocsconfig'][18]="Controlla prima che i duplicati siano gestiti in OCS-NG"; 
$LANG['ocsconfig'][19]="Importa unità per numero seriale"; 
$LANG['ocsconfig'][27]="Informazioni generali"; 
$LANG['ocsconfig'][36]="Modem"; 
$LANG['ocsconfig'][37]="Porte"; 
$LANG['ocsconfig'][38]="Usa il dizionario software di OCS-NG"; 
$LANG['ocsconfig'][39]="TAG OCS-NG"; 
$LANG['ocsconfig'][40]="Numero di computer da sincronizzare usando cron"; 
$LANG['ocsconfig'][41]="Registro"; 
$LANG['ocsconfig'][43]="Informazioni amministrative OCS-NG"; 
$LANG['ocsconfig'][48]="Comportamento quando disconnesso"; 
$LANG['ocsconfig'][49]="Cestino"; 
$LANG['ocsconfig'][50]="Cancellazione"; 
$LANG['ocsconfig'][52]="Connessione automatica delle macchine"; 
$LANG['ocsconfig'][53]="Attiva il link automatico"; 
$LANG['ocsconfig'][54]="Criteri di esistenza di un computer"; 
$LANG['ocsconfig'][55]="Trova i computer che hanno uno stato"; 
$LANG['ocsconfig'][56]="vuoto"; 
$LANG['ocsconfig'][57]="uguale"; 
$LANG['ocsconfig'][58]="La connessione unirà automaticamente il computer in GLPI con uno in OCS-NG.<br>Questa opzione viene presa in considerazione durante il collegamento manuale e dagli script di sincronizzazione."; 
$LANG['ocsconfig'][59]="Indirizzo della console OCS-NG (URL)"; 

$LANG['ocsng'][0]="OCS Inventory NG"; 
$LANG['ocsng'][1]="Sincronizza i computer già importati"; 
$LANG['ocsng'][2]="Importa nuovi computer"; 
$LANG['ocsng'][3]="Cancella il link tra GLPI e OCS-NG"; 
$LANG['ocsng'][4]="Collega i nuovi computer in OCS-NG a quelli esistenti in GLPI"; 
$LANG['ocsng'][5]="Importa nuovi computer"; 
$LANG['ocsng'][6]="Aggiornamento automatico"; 
$LANG['ocsng'][7]="Importato da OCS-NG"; 
$LANG['ocsng'][8]="Importazione effettuata"; 
$LANG['ocsng'][9]="Nessuna nuova macchina da importare"; 
$LANG['ocsng'][10]="Computer aggiornati in OCS-NG"; 
$LANG['ocsng'][11]="Aggiorna i computer"; 
$LANG['ocsng'][12]="Nessuna nuova macchina da aggiornare"; 
$LANG['ocsng'][13]="Data di importazione in GLPI"; 
$LANG['ocsng'][14]="Ultimo aggiornamento dei dati OCS-NG"; 
$LANG['ocsng'][15]="Nessun campo bloccato"; 
$LANG['ocsng'][16]="Campi bloccati"; 
$LANG['ocsng'][18]="Connessione al database OCS-NG riuscita"; 
$LANG['ocsng'][19]="Configurazione e versione OCS-NG valide"; 
$LANG['ocsng'][20]="Versione OCS-NG non valida: richiede almeno RC3"; 
$LANG['ocsng'][21]="Connessione al database OCS-NG fallita"; 
$LANG['ocsng'][22]="Attenzione! I dati importati (controlla la tua configurazione) savrascriveranno quelli esistenti"; 
$LANG['ocsng'][23]="Impossibile importarlo, il computer in GLPI è già collegato con un elemento di OCS-NG"; 
$LANG['ocsng'][24]="Forza la sincronizzazione"; 
$LANG['ocsng'][26]="Scelta del server OCS-NG"; 
$LANG['ocsng'][27]="Nessun server OCS-NG definito"; 
$LANG['ocsng'][29]="Server OCS-NG"; 
$LANG['ocsng'][30]="Monitor bloccati"; 
$LANG['ocsng'][32]="Dispositivi bloccati"; 
$LANG['ocsng'][34]="Stampanti bloccate"; 
$LANG['ocsng'][36]="Entità di destinazione"; 
$LANG['ocsng'][37]="Abilita anteprima"; 
$LANG['ocsng'][38]="Disabilita anteprima"; 
$LANG['ocsng'][40]="Regola di confronto ?"; 
$LANG['ocsng'][41]="Modo importazione manuale"; 
$LANG['ocsng'][42]="Configurazione OCS-NG non valida (TRACE_DELETED deve essere attivata)"; 
$LANG['ocsng'][43]="Accesso negato al database OCS-NG (necessita dei diritti di scrittura per la tabella hardware. CHECKSUM)"; 
$LANG['ocsng'][44]="Accesso negato al database OCS-NG (necessita dei diritti di cancellazione per la tabella deleted_equiv)"; 
$LANG['ocsng'][45]="OCS-NG ID"; 
$LANG['ocsng'][46]="Cancella in OCS-NG"; 
$LANG['ocsng'][47]="Collega con un computer in OCS-NG"; 
$LANG['ocsng'][48]="L'identificativo (ID) del computer in OCS-NG è cambiato"; 
$LANG['ocsng'][49]="Agente"; 
$LANG['ocsng'][50]="IP bloccati"; 
$LANG['ocsng'][52]="Software bloccati"; 
$LANG['ocsng'][54]="Software cancellato dalla sincronizzazione OCS-NG"; 
$LANG['ocsng'][55]="Volumi bloccati"; 
$LANG['ocsng'][57]="Interfaccia OCS-NG"; 

$LANG['pager'][1]="a"; 
$LANG['pager'][2]="da"; 
$LANG['pager'][3]="di"; 
$LANG['pager'][4]="Mostra"; 
$LANG['pager'][5]="elementi"; 

$LANG['peripherals'][18]="Marca"; 
$LANG['peripherals'][31]="Gestione globale"; 
$LANG['peripherals'][32]="gestione singola"; 
$LANG['peripherals'][33]="Tipo di gestione"; 

$LANG['phones'][18]="Marca"; 
$LANG['phones'][36]="Alimentazione"; 
$LANG['phones'][38]="Cuffia"; 
$LANG['phones'][39]="Vivavoce"; 
$LANG['phones'][40]="Numero di linee"; 

$LANG['planning'][0]="Il tecnico richiesto ha già un appuntamento nell'orario indicato"; 
$LANG['planning'][1]="Data errata. La data di inizio è successiva alla data di fine"; 
$LANG['planning'][5]="Giorno"; 
$LANG['planning'][6]="Settimana"; 
$LANG['planning'][8]="Interventi"; 
$LANG['planning'][9]="Da"; 
$LANG['planning'][10]="iCal"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Scarica l'agenda in formato iCal"; 
$LANG['planning'][13]="Sincronizzazione Webcal://"; 
$LANG['planning'][14]="Mese"; 
$LANG['planning'][15]="La tua agenda"; 
$LANG['planning'][16]="Informazione"; 
$LANG['planning'][17]="Da fare"; 
$LANG['planning'][18]="Fatto"; 

$LANG['plugins'][0]="Lista dei plugin"; 
$LANG['plugins'][2]="Installato / non configurato"; 
$LANG['plugins'][3]="Installato / non attivato"; 
$LANG['plugins'][4]="Errore / pulito"; 
$LANG['plugins'][5]="Funzioni inesistenti"; 
$LANG['plugins'][6]="Da aggionare"; 
$LANG['plugins'][7]="Nessun plugin installato"; 
$LANG['plugins'][8]="Mostra la lista dei plugin"; 
$LANG['plugins'][9]="Autori"; 
$LANG['plugins'][10]="Plugin incompatibile con la versione di GLPI in uso"; 

$LANG['printers'][14]="Seriale"; 
$LANG['printers'][15]="Parallela"; 
$LANG['printers'][18]="Porte"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Contatore pagine iniziale"; 
$LANG['printers'][31]="Pagine stampate"; 

$LANG['profiles'][0]="Diritti globali"; 
$LANG['profiles'][1]="Diritti locali"; 
$LANG['profiles'][2]="Interfaccia del profilo"; 
$LANG['profiles'][4]="Aggiungere commenti alle chiamate dei propri gruppi"; 
$LANG['profiles'][5]="Inserire una chiamata"; 
$LANG['profiles'][6]="Aggiungere un commento alle chiamate (richiedente)"; 
$LANG['profiles'][7]="Vedere le chiamate"; 
$LANG['profiles'][8]="Vedere tutti i commenti e gli incarichi (pubblici e privati)"; 
$LANG['profiles'][9]="Vedere commenti pubblici ed incarichi"; 
$LANG['profiles'][10]="Lettura"; 
$LANG['profiles'][11]="Scrittura"; 
$LANG['profiles'][12]="Nessun accesso"; 
$LANG['profiles'][13]="Profilo predefinito"; 
$LANG['profiles'][14]="Eliminare una chiamata"; 
$LANG['profiles'][15]="Aggiungere un commento ad ogni chiamata"; 
$LANG['profiles'][16]="Prendere in carico una chiamata"; 
$LANG['profiles'][17]="Riassegnare una chiamata"; 
$LANG['profiles'][18]="Aggiornare una chiamata"; 
$LANG['profiles'][19]="Assegnare una chiamata"; 
$LANG['profiles'][20]="Vedere la propria agenda"; 
$LANG['profiles'][21]="Vedere tutte le agende"; 
$LANG['profiles'][22]="Profilo"; 
$LANG['profiles'][23]="Gestire le prenotazioni"; 
$LANG['profiles'][24]="Cambiare la password"; 
$LANG['profiles'][26]="Vedere le chiamate create dai propri gruppi"; 
$LANG['profiles'][27]="Vedere i dispositivi dei propri gruppi"; 
$LANG['profiles'][28]="Ricorsivo"; 
$LANG['profiles'][29]="Dinamico"; 
$LANG['profiles'][30]="Vedere le informazioni su OCS-NG"; 
$LANG['profiles'][31]="Sincronizzare manualmente OCS-NG"; 
$LANG['profiles'][32]="Vedere le chiamate assegnate (personali + propri gruppi)"; 
$LANG['profiles'][33]="Nessun utente trovato"; 
$LANG['profiles'][34]="Legenda"; 
$LANG['profiles'][35]="Aggiornare tutti i commenti"; 
$LANG['profiles'][36]="Vedere l'agenda dei membri dei propri gruppi"; 
$LANG['profiles'][37]="Entità predefinita"; 
$LANG['profiles'][38]="Visualizza"; 
$LANG['profiles'][39]="Assegnazione"; 
$LANG['profiles'][40]="Modifica"; 
$LANG['profiles'][41]="Crea"; 
$LANG['profiles'][42]="Associa"; 
$LANG['profiles'][43]="Metodo di autenticazione e sincronizzazione degli utenti"; 
$LANG['profiles'][44]="Cambiare la priorità"; 
$LANG['profiles'][45]="Aggiungere un incarico a tutte le chiamate"; 
$LANG['profiles'][46]="Modificare tutti gli incarichi"; 
$LANG['profiles'][47]="Aggiungere utenti da una fonte esterna"; 
$LANG['profiles'][48]="Crea una richiesta di convalida"; 
$LANG['profiles'][49]="Convalidare una chiamata"; 

$LANG['registry'][1]="Hive"; 
$LANG['registry'][2]="Path"; 
$LANG['registry'][3]="Chiave/valore"; 
$LANG['registry'][4]="Chiavi di registro trovate"; 
$LANG['registry'][5]="Nessuna chiave trovata nel registro"; 
$LANG['registry'][6]="Nome OCS-NG"; 

$LANG['reminder'][0]="Note riservate"; 
$LANG['reminder'][1]="Note pubbliche"; 
$LANG['reminder'][6]="Inserisci nota"; 
$LANG['reminder'][9]="Testo"; 
$LANG['reminder'][12]="Aggiungi in agenda"; 
$LANG['reminder'][15]="Senza titolo"; 
$LANG['reminder'][16]="Note globali"; 

$LANG['reports'][0]="Seleziona il rapporto che vuoi creare"; 
$LANG['reports'][4]="Elenco dispositivi in manutenzione"; 
$LANG['reports'][11]="Dispositivi in manutenzione"; 
$LANG['reports'][12]="Tipo hardware"; 
$LANG['reports'][13]="Data"; 
$LANG['reports'][15]="Visualizza il rapporto"; 
$LANG['reports'][19]="Nome contatto"; 
$LANG['reports'][26]="Rapporto predefinito"; 
$LANG['reports'][27]="Per contratto"; 
$LANG['reports'][28]="Per anno"; 
$LANG['reports'][33]="Rapporto di rete"; 
$LANG['reports'][36]="Periferiche connesse"; 
$LANG['reports'][37]="Punti rete"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Per posizione"; 
$LANG['reports'][41]="Per switch"; 
$LANG['reports'][42]="Per punto rete"; 
$LANG['reports'][46]="porte switch"; 
$LANG['reports'][47]="porte dispositivo"; 
$LANG['reports'][49]="Rapporto di rete per switch"; 
$LANG['reports'][51]="Rapporto di rete per punto rete"; 
$LANG['reports'][52]="switch"; 
$LANG['reports'][54]="Rapporto di rete per posizione"; 
$LANG['reports'][57]="Elenco dispositivi"; 
$LANG['reports'][58]="Rapporto dispositivi per anno"; 
$LANG['reports'][60]="Data di apertura"; 
$LANG['reports'][61]="Data di chiusura"; 
$LANG['reports'][62]="Informazioni contabili sull'hardware"; 
$LANG['reports'][63]="Altre informazioni contabili (licenze, cartucce, materiali di consumo)"; 
$LANG['reports'][64]="Data di risoluzione"; 

$LANG['reservation'][1]="Dispositivi prenotabili"; 
$LANG['reservation'][2]="Dispositivo temporaneamente non disponibile"; 
$LANG['reservation'][3]="Fai click per renderlo non disponibile"; 
$LANG['reservation'][5]="Fai click per renderlo disponibile"; 
$LANG['reservation'][6]="Fai click per non autorizzare la prenotazione"; 
$LANG['reservation'][7]="Fai click per autorizzare la prenotazione"; 
$LANG['reservation'][8]="Prenota"; 
$LANG['reservation'][9]="Prenota un dispositivo"; 
$LANG['reservation'][16]="A"; 
$LANG['reservation'][17]="Da"; 
$LANG['reservation'][18]="Il dispositivo richiesto è già prenotato nel periodo indicato"; 
$LANG['reservation'][20]="Ritorna all'agenda"; 
$LANG['reservation'][21]="Mostra prenotazioni"; 
$LANG['reservation'][22]="Modifica commento"; 
$LANG['reservation'][25]="Tutti i dispositivi prenotabili"; 
$LANG['reservation'][27]="Periodicità"; 
$LANG['reservation'][28]="Settimanale"; 
$LANG['reservation'][29]="Giornaliera"; 
$LANG['reservation'][30]="volte"; 
$LANG['reservation'][31]="Per"; 
$LANG['reservation'][35]="Prenotazioni in corso e future"; 
$LANG['reservation'][36]="Prenotazioni nel passato"; 
$LANG['reservation'][37]="Nessuna prenotazione"; 
$LANG['reservation'][38]="Sei sicuro di voler rendere questo dispositivo non prenotabile?"; 
$LANG['reservation'][39]="Questa operazione eliminerà anche tutte le prenotazioni."; 
$LANG['reservation'][40]="Prenotazioni del materiale in scadenza oggi"; 

$LANG['rulesengine'][0]="è uguale a"; 
$LANG['rulesengine'][1]="non è uguale a"; 
$LANG['rulesengine'][2]="contiene"; 
$LANG['rulesengine'][3]="non contiene"; 
$LANG['rulesengine'][4]="inizia con"; 
$LANG['rulesengine'][5]="finisce con"; 
$LANG['rulesengine'][6]="Criteri"; 
$LANG['rulesengine'][7]="Azioni"; 
$LANG['rulesengine'][8]="Gestione regole"; 
$LANG['rulesengine'][9]="Operatore logico"; 
$LANG['rulesengine'][10]="Posizione"; 
$LANG['rulesengine'][11]="Tipo azione"; 
$LANG['rulesengine'][12]="Campi"; 
$LANG['rulesengine'][13]="Valore"; 
$LANG['rulesengine'][14]="Condizioni"; 
$LANG['rulesengine'][15]="Motivi"; 
$LANG['rulesengine'][16]="Criterio"; 
$LANG['rulesengine'][17]="Regole"; 
$LANG['rulesengine'][18]="Regole per l'assegnazione dei dispositivo ad un'entità"; 
$LANG['rulesengine'][19]="Regole assegnazione entità e diritti"; 
$LANG['rulesengine'][20]="Regole ereditate"; 
$LANG['rulesengine'][21]="Regole dell'entità figlio"; 
$LANG['rulesengine'][22]="Assegna"; 
$LANG['rulesengine'][23]="Regole locali"; 
$LANG['rulesengine'][24]="Scegli tipo regola"; 
$LANG['rulesengine'][25]="Nome computer"; 
$LANG['rulesengine'][26]="Controlli sulle espressioni regolari"; 
$LANG['rulesengine'][27]="Non corrisponde ad un'espressione regolare"; 
$LANG['rulesengine'][28]="Regole di lavorazione dei commenti"; 
$LANG['rulesengine'][29]="Lista regole"; 
$LANG['rulesengine'][30]="Azione"; 
$LANG['rulesengine'][33]="Vocabolario elenchi"; 
$LANG['rulesengine'][35]="Vocabolario software"; 
$LANG['rulesengine'][36]="Vocabolario produttori"; 
$LANG['rulesengine'][37]="Regole assegnazione categoria a software"; 
$LANG['rulesengine'][38]="Ricalcola"; 
$LANG['rulesengine'][40]="la categoria"; 
$LANG['rulesengine'][41]="Convalida"; 
$LANG['rulesengine'][42]="AND"; 
$LANG['rulesengine'][43]="OR"; 
$LANG['rulesengine'][45]="Assegna valore da un'espressione regolare"; 
$LANG['rulesengine'][46]="Assegnare: attrezzature su IP"; 
$LANG['rulesengine'][47]="Assegnare: attrezzature su nome + dominio"; 
$LANG['rulesengine'][48]="Assegna attrezzature"; 
$LANG['rulesengine'][49]="Assegnare: materiale sull'indirizzo MAC"; 
$LANG['rulesengine'][50]="Vocabolario modelli computer"; 
$LANG['rulesengine'][51]="Vocabolario modelli schermi"; 
$LANG['rulesengine'][52]="Vocabolario modelli telefoni"; 
$LANG['rulesengine'][53]="Vocabolario modelli periferiche"; 
$LANG['rulesengine'][54]="Vocabolario modelli stampanti"; 
$LANG['rulesengine'][55]="Vocabolario modelli apparati di rete"; 
$LANG['rulesengine'][56]="Modelli"; 
$LANG['rulesengine'][60]="Vocabolario tipo computer"; 
$LANG['rulesengine'][61]="Vocabolario tipo schermo"; 
$LANG['rulesengine'][62]="Vocabolario tipo telefono"; 
$LANG['rulesengine'][63]="Vocabolario tipo periferica"; 
$LANG['rulesengine'][64]="Vocabolario tipo stampante"; 
$LANG['rulesengine'][65]="Vocabolario tipo apparato di rete"; 
$LANG['rulesengine'][66]="Tipi"; 
$LANG['rulesengine'][67]="Vocabolario Sistemi Operativi (SO)"; 
$LANG['rulesengine'][68]="Vocabolario service pack"; 
$LANG['rulesengine'][69]="Vocabolario versioni"; 
$LANG['rulesengine'][70]="Regole per l'assegnazione di una chiamata creata tramite e-mail"; 
$LANG['rulesengine'][76]="Esegui vocabolario"; 
$LANG['rulesengine'][77]="Vocabolari"; 
$LANG['rulesengine'][78]="Versione"; 
$LANG['rulesengine'][79]="Aggiungi risultato da un'espressione regolare"; 
$LANG['rulesengine'][80]="Vocabolario generale"; 
$LANG['rulesengine'][81]="Esito regola"; 
$LANG['rulesengine'][82]="Dettaglio risultato"; 
$LANG['rulesengine'][83]="Puoi influenzare il risultato di una regex con la sequenza #0"; 
$LANG['rulesengine'][84]="Verifica gestore delle regole"; 
$LANG['rulesengine'][85]="Esito regex"; 
$LANG['rulesengine'][86]="Categoria del software quando viene cancellato dal vocabolario"; 
$LANG['rulesengine'][87]="Software cancellato da vocabolario GLPI"; 
$LANG['rulesengine'][90]="Elaborazione in corso..."; 
$LANG['rulesengine'][91]="Elaborazione terminata."; 
$LANG['rulesengine'][92]="Avviso precedente esecuzione vocabolario"; 
$LANG['rulesengine'][93]="Attenzione! Questa operazione può spostare del software nel cestino.<br>Accertati di notificarlo agli utenti."; 
$LANG['rulesengine'][94]="UNIONE"; 
$LANG['rulesengine'][95]="Scegli produttore"; 
$LANG['rulesengine'][96]="Esegui vocabolario su produttori<br> ('-----' = tutti)"; 
$LANG['rulesengine'][97]="Nessun elemento da verificare"; 
$LANG['rulesengine'][100]="Informazioni sulla cache"; 
$LANG['rulesengine'][102]="Nome regola"; 
$LANG['rulesengine'][103]="Oggetti in cache"; 
$LANG['rulesengine'][104]="Valore originale"; 
$LANG['rulesengine'][105]="Valore modificato"; 
$LANG['rulesengine'][106]="Non modificata"; 
$LANG['rulesengine'][107]="Inattiva"; 
$LANG['rulesengine'][108]="originale"; 
$LANG['rulesengine'][110]="Assegnazione diritti"; 
$LANG['rulesengine'][111]="Assegnazione entità"; 
$LANG['rulesengine'][112]="Assegnazione entità e diritti"; 
$LANG['rulesengine'][120]="Il gestore termina alla prima regola soddisfatta"; 
$LANG['rulesengine'][121]="Il gestore convalida tutte le regole."; 
$LANG['rulesengine'][122]="Il gestore passa l'esito di una regola alla successiva."; 
$LANG['rulesengine'][130]="Entità da LDAP"; 
$LANG['rulesengine'][131]="Entità da TAG"; 
$LANG['rulesengine'][132]="Ignorare l'importazione"; 
$LANG['rulesengine'][133]="Entità da dominio"; 
$LANG['rulesengine'][134]="Rifiuta e-mail (senza e-mail di risposta)"; 
$LANG['rulesengine'][135]="Rifiuta e-mail (con e-mail di risposta)"; 
$LANG['rulesengine'][138]="Criteri LDAP"; 
$LANG['rulesengine'][140]="Aggiungi un criterio"; 
$LANG['rulesengine'][142]="Lista delle e-mail non importate"; 
$LANG['rulesengine'][144]="Entità dal profilo utente"; 
$LANG['rulesengine'][145]="Utente con profilo singolo"; 
$LANG['rulesengine'][146]="Utente con profilo"; 
$LANG['rulesengine'][147]="Utente con profilo singolo"; 
$LANG['rulesengine'][148]="dominio e-mail conosciuto"; 
$LANG['rulesengine'][150]="Le regole che influenzavano l'entità sono state disabilitate."; 

$LANG['search'][0]="Cerca"; 
$LANG['search'][1]="per tutti"; 
$LANG['search'][2]="contiene"; 
$LANG['search'][4]="ordinato per"; 
$LANG['search'][8]="Data inizio"; 
$LANG['search'][9]="Data termine"; 
$LANG['search'][10]="in"; 
$LANG['search'][11]="Elementi visualizzati"; 
$LANG['search'][12]="Indicare una data di termine"; 
$LANG['search'][15]="Nessun elemento trovato"; 
$LANG['search'][16]="Almeno"; 
$LANG['search'][17]="Aggiungi criterio di ricerca"; 
$LANG['search'][18]="Rimuovi un criterio di ricerca"; 
$LANG['search'][19]="Aggiungi criterio di ricerca globale"; 
$LANG['search'][20]="Rimuovi un criterio globale di ricerca"; 

$LANG['setup'][0]="Configurazione elenchi"; 
$LANG['setup'][2]="Aggiungi utente..."; 
$LANG['setup'][3]="Collegamento directory LDAP"; 
$LANG['setup'][4]="Tipo computer"; 
$LANG['setup'][5]="Sistemi Operativi"; 
$LANG['setup'][6]="Personalizzazione"; 
$LANG['setup'][9]="Schede di rete"; 
$LANG['setup'][10]="Ordine di visualizzazione del nome completo"; 
$LANG['setup'][14]="E-mail"; 
$LANG['setup'][18]="Login"; 
$LANG['setup'][19]="Password"; 
$LANG['setup'][20]="Conferma password"; 
$LANG['setup'][21]="Errore : le due password non sono uguali"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Commenti privati per impostazione predefinita"; 
$LANG['setup'][40]="Incarichi privati per impostazione predefinita"; 
$LANG['setup'][41]="Seleziona la lingua"; 
$LANG['setup'][42]="Modelli apparati di rete"; 
$LANG['setup'][43]="Tipo stampanti"; 
$LANG['setup'][44]="Tipo schermi"; 
$LANG['setup'][45]="Tipo case"; 
$LANG['setup'][46]="Valore predefinito"; 
$LANG['setup'][47]="Tipo di grafico predefinito"; 
$LANG['setup'][48]="Valori predefiniti"; 
$LANG['setup'][62]="Seleziona categoria"; 
$LANG['setup'][63]="Attenzione, stai eliminando una descrizione usata da uno o più oggetti"; 
$LANG['setup'][64]="Se confermi l'eliminazione, i dispositivi che usano questo attributo avranno tale valore azzerato"; 
$LANG['setup'][65]="Puoi sostituire tutte le occorrenze di questa voce con un'altra:"; 
$LANG['setup'][67]="Fonti esterne di autenticazione"; 
$LANG['setup'][69]="Tipo periferiche"; 
$LANG['setup'][70]="Configurazione generale"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Punto rete"; 
$LANG['setup'][74]="Non puoi eliminare questa posizione perché ha delle sotto-posizioni"; 
$LANG['setup'][75]="Come figlio di"; 
$LANG['setup'][79]="Categorie chiamate"; 
$LANG['setup'][80]="Tipo rapporti"; 
$LANG['setup'][81]="Categorie documenti"; 
$LANG['setup'][82]="Tipo indirizzo"; 
$LANG['setup'][83]="Stato dispositivi"; 
$LANG['setup'][84]="Tipo cartucce"; 
$LANG['setup'][85]="Tipo contratti"; 
$LANG['setup'][86]="Tipo memorie RAM"; 
$LANG['setup'][87]="Categorie Knowledge base"; 
$LANG['setup'][88]="Rete"; 
$LANG['setup'][89]="Dominio"; 
$LANG['setup'][90]="VLAN"; 
$LANG['setup'][91]="Modelli computer"; 
$LANG['setup'][92]="Tipo materiali di consumo"; 
$LANG['setup'][93]="Tipo interfacce (hard disk, ...)"; 
$LANG['setup'][94]="Modelli schermi"; 
$LANG['setup'][95]="Modelli apparati di rete"; 
$LANG['setup'][96]="Modelli stampanti"; 
$LANG['setup'][97]="Modelli periferiche"; 
$LANG['setup'][98]="Categoria incarichi"; 
$LANG['setup'][99]="Numero di Build"; 
$LANG['setup'][100]="Numero della stanza"; 
$LANG['setup'][101]="Numero massimo di azioni automatiche simultanee (esecuzione CLI)"; 
$LANG['setup'][102]="Livello log"; 
$LANG['setup'][103]="1- Critici (solo errori di login)"; 
$LANG['setup'][104]="2- Gravi (non usato)"; 
$LANG['setup'][105]="3- Importanti (connessioni riuscite)"; 
$LANG['setup'][106]="4- Avvisi (inserimento, cancellazione, monitoraggio)"; 
$LANG['setup'][107]="5- Completo (tutti)"; 
$LANG['setup'][109]="Per quanto tempo, in giorni, i log di sistema sono tenuti in archivio (0=sempre)"; 
$LANG['setup'][110]="Mostra le nuove chiamate nella pagina principale"; 
$LANG['setup'][111]="Numero massimo di elementi da visualizzare in una pagina"; 
$LANG['setup'][112]="Numero massimo dei caratteri per ciascun elemento dei menù a discesa"; 
$LANG['setup'][113]="Lingua predefinita"; 
$LANG['setup'][114]="Colori delle priorità"; 
$LANG['setup'][115]="Soglia di allerta predefinita materiali di consumo e cartucce"; 
$LANG['setup'][116]="Assegnazione automatica chiamata al responsabile tecnico indicato"; 
$LANG['setup'][117]="Autorizza accesso anonimo alle FAQ"; 
$LANG['setup'][118]="Testo sulla pagina di login"; 
$LANG['setup'][119]="Configura visualizzazione"; 
$LANG['setup'][120]="Utilizza la visualizzazione dinamica per le liste ed i campi testo"; 
$LANG['setup'][121]="Carattere jolly per la visualizzazione dinamica"; 
$LANG['setup'][122]="Numero massimo di elementi visualizzati nei menù a discesa, quando non vengono utilizzati caratteri jolly"; 
$LANG['setup'][123]="Non usare la visualizzazione dinamica se il numero degli elementi è minore di (0=mai)"; 
$LANG['setup'][124]="Aggiungi automaticamente utenti da fonte esterna di autenticazione"; 
$LANG['setup'][125]="... da fonte esterna"; 
$LANG['setup'][126]="Aggiungi automaticamente utente da fonte esterna di autenticazione"; 
$LANG['setup'][127]="Completamento automatico dei campi di testo"; 
$LANG['setup'][128]="Formato data"; 
$LANG['setup'][129]="Mostra gli ID GLPI"; 
$LANG['setup'][130]="Per quanto tempo, in giorni, i log delle azioni sono tenuti in archivio (0=sempre)"; 
$LANG['setup'][132]="Visualizza il nome completo nei menù a discesa"; 
$LANG['setup'][133]="Attiva il modo OCS-NG"; 
$LANG['setup'][134]="Modo OCS-NG"; 
$LANG['setup'][135]="Normale"; 
$LANG['setup'][136]="Traduzione"; 
$LANG['setup'][137]="Debug"; 
$LANG['setup'][138]="Utilizza GLPI in modo"; 
$LANG['setup'][139]="Generale"; 
$LANG['setup'][140]="Tipi"; 
$LANG['setup'][145]="Sistema Operativo"; 
$LANG['setup'][147]="Visualizzazione dinamica"; 
$LANG['setup'][148]="Passo per intervalli di tempo"; 
$LANG['setup'][149]="Numero decimali per valuta"; 
$LANG['setup'][150]="Formato numeri"; 
$LANG['setup'][154]="Basedn"; 
$LANG['setup'][155]="rootdn (per connessioni non anonime)"; 
$LANG['setup'][156]="Password (per connessioni non anonime)"; 
$LANG['setup'][157]="L'estensione LDAP dell'interprete PHP non è installata"; 
$LANG['setup'][158]="Impossibile usare LDAP come fonte esterna di autenticazione"; 
$LANG['setup'][159]="Filtro connessione"; 
$LANG['setup'][162]="Configurazione IMAP/POP"; 
$LANG['setup'][164]="Nome dominio IMAP/POP <br>(le e-mail saranno del tipo login@dominio)"; 
$LANG['setup'][165]="L'estensione IMAP dell'interprete PHP non è installata"; 
$LANG['setup'][166]="Impossibile usare IMAP/POP come fonte esterna di autenticazione"; 
$LANG['setup'][167]="Collegamenti GLPI/LDAP"; 
$LANG['setup'][168]="Opzioni connessione"; 
$LANG['setup'][169]="Archivio messaggi (opzionale, di solito INBOX)"; 
$LANG['setup'][170]="Stringa di connessione"; 
$LANG['setup'][171]="Porta (opzionale)"; 
$LANG['setup'][172]="Porta LDAP (predefinita = 389)"; 
$LANG['setup'][174]="Server CAS"; 
$LANG['setup'][175]="Porta"; 
$LANG['setup'][176]="Directory radice (opzionale)"; 
$LANG['setup'][177]="Configurazione CAS"; 
$LANG['setup'][178]="Le estensioni CURL o DOMXML dell'interprete PHP non sono installate"; 
$LANG['setup'][179]="Impossibile usare CAS come fonte di connessione"; 
$LANG['setup'][180]="Utilizza TLS"; 
$LANG['setup'][181]="La funzione ldap_start_tls non esiste"; 
$LANG['setup'][182]="Indirizzo web di destinazione alla disconnessione (logout)"; 
$LANG['setup'][185]="Log in file distinti (SQL, e-mail, cron...)"; 
$LANG['setup'][186]="Fuso orario"; 
$LANG['setup'][190]="Certificato X.509"; 
$LANG['setup'][191]="Attributo e-mail per X.509"; 
$LANG['setup'][192]="Attivato"; 
$LANG['setup'][193]="Campo per la registrazione della login nell'array _SERVER"; 
$LANG['setup'][194]="Ottieni informazioni aggiuntive da directory LDAP"; 
$LANG['setup'][195]="Conserva stato"; 
$LANG['setup'][196]="Cancella lo stato"; 
$LANG['setup'][197]="Prende stato dal computer"; 
$LANG['setup'][198]="Prende stato"; 
$LANG['setup'][199]="Eliminare il dominio di login sotto forma di login@dominio"; 
$LANG['setup'][200]="Infinito"; 
$LANG['setup'][201]="Configurazione"; 
$LANG['setup'][202]="Abilita commenti via e-mail"; 
$LANG['setup'][203]="E-mail amministratore (mittente)"; 
$LANG['setup'][204]="Firma nelle e-mail"; 
$LANG['setup'][205]="E-mail di test inviata all'amministratore"; 
$LANG['setup'][206]="Test invio e-mail all'amministratore fallito"; 
$LANG['setup'][207]="E-mail amministratore per le risposte (se necessaria)"; 
$LANG['setup'][217]="La funzione mail di PHP non funziona o non è stata attivata nel tuo server"; 
$LANG['setup'][218]="L'utilizzo di un server SMTP è indispensabile"; 
$LANG['setup'][219]="Abilita la richiesta di intervento anonima (helpdesk.html)"; 
$LANG['setup'][221]="Inizio dell'anno fiscale (giorno e mese)"; 
$LANG['setup'][223]="Orari limite per la pianificazione degli interventi"; 
$LANG['setup'][227]="Indirizzo web dell'applicazione (URL)"; 
$LANG['setup'][228]="Nome utente"; 
$LANG['setup'][229]="Invia una e-mail di test all'amministratore"; 
$LANG['setup'][231]="Usa un server SMTP per inviare le e-mail"; 
$LANG['setup'][232]="Server SMTP"; 
$LANG['setup'][234]="Utente server SMTP (opzionale)"; 
$LANG['setup'][235]="Password server SMTP (opzionale)"; 
$LANG['setup'][236]="Precedente tecnico incaricato della chiamata"; 
$LANG['setup'][237]="Amministratore"; 
$LANG['setup'][239]="Tecnico incaricato della chiamata"; 
$LANG['setup'][240]="Opzioni notifica"; 
$LANG['setup'][241]="Nessun criterio personale. Vuoi personalizzare i parametri?"; 
$LANG['setup'][242]="Opzioni allerte"; 
$LANG['setup'][243]="Allerte materiali di consumo"; 
$LANG['setup'][244]="Allerte cartucce"; 
$LANG['setup'][245]="Frequenza del promemoria"; 
$LANG['setup'][246]="Allerte contratti"; 
$LANG['setup'][247]="Allerte informazioni contabili"; 
$LANG['setup'][248]="Gruppo incaricato della chiamata"; 
$LANG['setup'][249]="Gruppo richiedente"; 
$LANG['setup'][250]="Campi di ricerca predefiniti"; 
$LANG['setup'][252]="Seleziona elementi visualizzati per impostazione predefinita"; 
$LANG['setup'][253]="Filtro di ricerca nei gruppi"; 
$LANG['setup'][254]="Tipo ricerca"; 
$LANG['setup'][255]="Attributo del gruppo contenente gli utenti"; 
$LANG['setup'][256]="Negli utenti"; 
$LANG['setup'][257]="Nei gruppi"; 
$LANG['setup'][258]="Utenti e gruppi"; 
$LANG['setup'][259]="Appartenenze ai gruppi"; 
$LANG['setup'][260]="Attributo utente riferito ai suoi gruppi"; 
$LANG['setup'][261]="DN del gruppo"; 
$LANG['setup'][262]="Usa DN nella ricerca"; 
$LANG['setup'][263]="Filtro di ricerca negli utenti"; 
$LANG['setup'][264]="Allerte scadenza licenze"; 
$LANG['setup'][271]="Limita gestione video"; 
$LANG['setup'][272]="Limita gestione periferiche"; 
$LANG['setup'][273]="Limita gestione telefoni"; 
$LANG['setup'][274]="per aggiunta manuale"; 
$LANG['setup'][275]="Limita gestione stampanti"; 
$LANG['setup'][280]="Aggiornamento automatico dei dispositivi collegati al computer"; 
$LANG['setup'][281]="Comportamento alla connessione/aggiornamento"; 
$LANG['setup'][282]="Comportamento alla disconnessione"; 
$LANG['setup'][283]="Copia"; 
$LANG['setup'][284]="Pulisci"; 
$LANG['setup'][285]="Non copiare"; 
$LANG['setup'][286]="Non cancellare"; 
$LANG['setup'][300]="Verifica se è presente una versione aggiornata"; 
$LANG['setup'][301]="E' disponibile una nuova versione:"; 
$LANG['setup'][302]="Disponibile sul sito GLPI-PROJECT.org"; 
$LANG['setup'][303]="Stai utilizzando l'ultima versione disponibile"; 
$LANG['setup'][304]="Verifica connessione fallita. Se utilizzi un server proxy, configuralo."; 
$LANG['setup'][305]="Ogni giorno"; 
$LANG['setup'][306]="Verifica aggiornamenti"; 
$LANG['setup'][307]="Mai"; 
$LANG['setup'][308]="Ogni settimana"; 
$LANG['setup'][309]="Ogni mese"; 
$LANG['setup'][310]="Impossibile connettersi al sito."; 
$LANG['setup'][311]="Connessione al server proxy fallita"; 
$LANG['setup'][312]="Nessun dato disponibile sul sito"; 
$LANG['setup'][313]="Attenzione : non c'è il valore predefinito"; 
$LANG['setup'][350]="Dispositivi associabili alla chiamata"; 
$LANG['setup'][351]="Tutti i dispositivi"; 
$LANG['setup'][352]="Dispositivi collegabili ad una chiamata"; 
$LANG['setup'][360]="Campi automatici (indicati da *)"; 
$LANG['setup'][400]="Configurazione del proxy"; 
$LANG['setup'][407]="Indirizzo della pagina di aiuto dell'interfaccia semplificata"; 
$LANG['setup'][408]="Indirizzo della pagina di aiuto dell'interfaccia standard"; 
$LANG['setup'][409]="Intestazione predefinita quando si associa un documento ad una chiamata"; 
$LANG['setup'][503]="Modelli telefoni"; 
$LANG['setup'][504]="Tipo telefoni"; 
$LANG['setup'][505]="Tipo alimentazione telefoni"; 
$LANG['setup'][601]="Valore LDAP"; 
$LANG['setup'][602]="Connessione al database OCS-NG"; 
$LANG['setup'][603]="Aggiungi utente"; 
$LANG['setup'][604]="Associa a gruppo"; 
$LANG['setup'][606]="Impossibile aggiungere. Utente già presente."; 
$LANG['setup'][607]="Associa ad un profilo"; 
$LANG['setup'][608]="Per impostazione predefinita, i software sono visibili nell'helpdesk"; 
$LANG['setup'][609]="Impossibile inserirlo. Il server OCS-NG è già presente."; 
$LANG['setup'][610]="Titolo chiamata obbligatorio"; 
$LANG['setup'][611]="Descrizione chiamata obbligatoria"; 
$LANG['setup'][612]="Categoria chiamata obbligatoria"; 
$LANG['setup'][613]="Aggiungi un utente LDAP senza diritti"; 
$LANG['setup'][614]="Impossibile aggiornare la login. L'utente è già presente."; 
$LANG['setup'][615]="Ciclo di vita delle chiamate"; 
$LANG['setup'][616]="Da \ A"; 
$LANG['setup'][620]="Collegamento"; 
$LANG['setup'][621]="Filtro di ricerca delle entità"; 
$LANG['setup'][622]="Attributo rappresentante l'entità"; 
$LANG['setup'][623]="Importa le entità da directory LDAP"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="E-mail server"; 
$LANG['setup'][661]="Non è stato possibile configurare le notifiche: per favore abilita i commenti per e-mail"; 
$LANG['setup'][703]="Generale"; 
$LANG['setup'][704]="Notifiche"; 
$LANG['setup'][707]="Invio avvisi di prenotazioni"; 
$LANG['setup'][708]="Avvisa se le chiamate non sono ancora risolte dopo"; 
$LANG['setup'][720]="Informazioni sul sistema"; 
$LANG['setup'][721]="Informazioni sul sistema, l'installazione e la configurazione"; 
$LANG['setup'][722]="Da copiare/incollare al momento della richiesta di assistenza"; 
$LANG['setup'][731]="Valore in configurazione generale"; 
$LANG['setup'][732]="Dominio e-mail"; 
$LANG['setup'][800]="Replica MySQL"; 
$LANG['setup'][801]="Attiva la replica MySQL"; 
$LANG['setup'][802]="Base"; 
$LANG['setup'][803]="Scarto tra master e slave"; 
$LANG['setup'][806]="Periodo massimo fuori sincronia (in minuti)"; 
$LANG['setup'][807]="Il database slave non è sincronizzato. Lo scarto è di:"; 
$LANG['setup'][808]="Database slave non sincronizzato!"; 
$LANG['setup'][809]="Replica MySQL: solo lettura"; 
$LANG['setup'][810]="Elimina sincronizzazione replica MySQL"; 

$LANG['software'][1]="Versione acquisita"; 
$LANG['software'][2]="Versione in uso"; 
$LANG['software'][3]="Licenze interessate non installate"; 
$LANG['software'][4]="Illimitata"; 
$LANG['software'][5]="Versione"; 
$LANG['software'][6]="Editore"; 
$LANG['software'][7]="Aggiungi una versione"; 
$LANG['software'][8]="Aggiungi una licenza"; 
$LANG['software'][11]="Licenze"; 
$LANG['software'][17]="Software installato"; 
$LANG['software'][19]="Installazioni"; 
$LANG['software'][20]="Rimanenti"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Aggiornamento"; 
$LANG['software'][30]="Tipo di licenze"; 
$LANG['software'][32]="Termine"; 
$LANG['software'][44]="Installa"; 
$LANG['software'][45]="Disinstalla software"; 
$LANG['software'][46]="Visibile in Helpdesk"; 
$LANG['software'][47]="Raggruppamento"; 
$LANG['software'][48]="Consolidare"; 
$LANG['software'][49]="Software cancellato dopo la riunificazione"; 
$LANG['software'][50]="Assegnato al computer"; 
$LANG['software'][51]="Il numero deve essere 1 per essere in grado di incidere"; 

$LANG['softwarecategories'][2]="Software libero"; 
$LANG['softwarecategories'][3]="Mostra il software non appartenente ad una categoria"; 
$LANG['softwarecategories'][4]="Mostra il software appartenente ad una categoria"; 
$LANG['softwarecategories'][5]="Categorie software"; 

$LANG['state'][0]="Stato"; 
$LANG['state'][6]="Tipo elemento"; 
$LANG['state'][7]="Nessun elemento trovato"; 
$LANG['state'][11]="Prospetto"; 

$LANG['stats'][0]="Seleziona statistica"; 
$LANG['stats'][1]="Generale"; 
$LANG['stats'][2]="Nessun elemento da visualizzare"; 
$LANG['stats'][3]="Per componente"; 
$LANG['stats'][5]="Numero totale delle chiamate"; 
$LANG['stats'][6]="Tempo medio di attesa per risoluzione chiamata"; 
$LANG['stats'][7]="Mostra i grafici"; 
$LANG['stats'][11]="Numero chiamate evase"; 
$LANG['stats'][13]="Numero delle chiamate"; 
$LANG['stats'][15]="Tempo medio di risoluzione chiamata"; 
$LANG['stats'][16]="Nome tecnico"; 
$LANG['stats'][20]="Nome utente"; 
$LANG['stats'][23]="Nessuna statistica disponibile"; 
$LANG['stats'][25]="Tempo medio effettivo di intervento"; 
$LANG['stats'][27]="Tempo totale effettivo di intervento"; 
$LANG['stats'][30]="Tempo medio di attesa per assegnazione chiamata"; 
$LANG['stats'][31]="Giorni"; 
$LANG['stats'][33]="Min."; 
$LANG['stats'][34]="Sec."; 
$LANG['stats'][35]="Chiamate"; 
$LANG['stats'][44]="Nome azienda"; 
$LANG['stats'][45]="Per dispositivo"; 
$LANG['stats'][47]="Per chiamata"; 
$LANG['stats'][48]="(assegnata)"; 
$LANG['stats'][49]="(commenti)"; 

$LANG['title'][5]="Knowledge base"; 
$LANG['title'][6]="Apparati di rete"; 
$LANG['title'][9]="Stato dispositivi"; 
$LANG['title'][10]="Gestione chiamate"; 
$LANG['title'][13]="Informazioni utente"; 
$LANG['title'][14]="Sorgenti autenticazione esterne"; 
$LANG['title'][24]="Assistenza"; 
$LANG['title'][26]="Principale"; 
$LANG['title'][27]="Connessioni"; 
$LANG['title'][28]="Chiamate"; 
$LANG['title'][30]="Componenti"; 
$LANG['title'][33]="Collegamenti esterni"; 
$LANG['title'][34]="Collegamenti"; 
$LANG['title'][37]="Note"; 
$LANG['title'][38]="Storico"; 
$LANG['title'][40]="Note pubbliche e riservate"; 
$LANG['title'][42]="Modifica generalizzata"; 
$LANG['title'][43]="Registro"; 

$LANG['tracking'][1]="I miei dispositivi"; 
$LANG['tracking'][2]="oppure ricerca globale"; 
$LANG['tracking'][3]="Date errate. Variazione annullata."; 
$LANG['tracking'][4]="Non è stata selezionata la priorità, per favore specificala."; 
$LANG['tracking'][8]="La chiamata non ha una descrizione del problema, inseriscila."; 
$LANG['tracking'][9]="Origine predefinita della chiamata"; 
$LANG['tracking'][10]="Origine predefinita dei destinatari dell'e-mail"; 
$LANG['tracking'][24]="Documentazione chiamata"; 
$LANG['tracking'][29]="Quantità"; 
$LANG['tracking'][30]="Nuove"; 
$LANG['tracking'][31]="In lavorazione (assegnate)"; 
$LANG['tracking'][32]="In lavorazione (pianificate)"; 
$LANG['tracking'][34]="Diretta"; 
$LANG['tracking'][35]="Scritta"; 
$LANG['tracking'][37]="Preserva le chiamate quando vengono eliminati i dispositivi dall'inventario"; 
$LANG['tracking'][38]="E-mail di commento inviata a"; 
$LANG['tracking'][39]="Visibile nell'interfaccia semplificata"; 

$LANG['transfer'][1]="Trasferimento"; 
$LANG['transfer'][3]="Se non più usato"; 
$LANG['transfer'][4]="Svuota la lista dei dispositivi da trasferire"; 
$LANG['transfer'][5]="Puoi continuare ad aggiungere dispositivi da trasferire o eseguire ora il tresferimento"; 
$LANG['transfer'][6]="Ti consiglio di fare un salvataggio prima di trasferire i dispositivi"; 
$LANG['transfer'][7]="Dispositivi da trasferire"; 
$LANG['transfer'][8]="Modo di trasferimento"; 

$LANG['update'][88]="La versione del database non è compatibile con la versione del programma installato.<br>E' necessario un aggiornamento."; 
$LANG['update'][89]="Stai cercando di utilizzare GLPI con un database creato per una versione superiore. Per piacere, installa la versione di GLPI compatibile con il tuo database."; 
$LANG['update'][90]="Errore durante l'aggiornamento del database"; 
$LANG['update'][91]="Attenzione!"; 
$LANG['update'][92]="Stai per aggiornare il database GLPI denominato:"; 
$LANG['update'][93]="Connessione al database riuscita"; 
$LANG['update'][94]="Aggiornamento riuscito. Il tuo database è aggiornato"; 
$LANG['update'][95]="Connessione al database fallita, verifica i parametri di connessione contenuti nel file config_db.php"; 
$LANG['update'][96]="Ora tutti gli amministratori hanno i diritti di 'super-admin'. E' stato anche aggiunto questo nuovo profilo utente."; 
$LANG['update'][105]="Impossibile completare l'aggiornamento in questa maniera!"; 
$LANG['update'][106]="Ritorna a GLPI"; 
$LANG['update'][107]="Ora devi procedere all'aggiornamento del contenuto del tuo database"; 
$LANG['update'][130]="Aggiornamento posizioni"; 
$LANG['update'][131]="La nuova struttura è gerarchica"; 
$LANG['update'][132]="Se hai usato un carattere di separazione, lo puoi indicare per automatizzare la generazione della gerarchia"; 
$LANG['update'][133]="Puoi anche specificare una posizione radice che includerà tutte le posizioni generate."; 
$LANG['update'][134]="Carattere di separazione"; 
$LANG['update'][135]="Posizione radice"; 
$LANG['update'][136]="Questa è la nuova gerarchia. Se corretta, la puoi confermare."; 
$LANG['update'][137]="Nuova gerarchia"; 
$LANG['update'][138]="Posizioni attuali"; 
$LANG['update'][139]="Ottimizzazione tabelle"; 
$LANG['update'][140]="Creazione dell'indice"; 
$LANG['update'][141]="Cambio della struttura del database"; 
$LANG['update'][142]="Migrazione dei dati"; 

$LANG['users'][1]="Titolo"; 
$LANG['users'][2]="Categoria"; 

$LANG['validation'][0]="Convalida"; 
$LANG['validation'][1]="Invia una richiesta di convalida"; 
$LANG['validation'][2]="Stato"; 
$LANG['validation'][3]="Data di richiesta"; 
$LANG['validation'][4]="Data di convalida"; 
$LANG['validation'][5]="Richiesta di commento"; 
$LANG['validation'][6]="Commento alla convalida"; 
$LANG['validation'][7]="Convalida per la chiamata"; 
$LANG['validation'][9]="In attesa di convalida"; 
$LANG['validation'][10]="Rifiutato"; 
$LANG['validation'][11]="Accettato"; 
$LANG['validation'][12]="Non soggetto a convalida"; 
$LANG['validation'][13]="Richieste di convalida inviate a"; 
$LANG['validation'][15]="Chiamate in attesa della tua convalida"; 
$LANG['validation'][16]="Facoltativo se accettato"; 
$LANG['validation'][18]="Richiesta di convalida"; 
$LANG['validation'][19]="Convalida accettata"; 
$LANG['validation'][20]="Convalida negata"; 
$LANG['validation'][21]="Utente validatore"; 
$LANG['validation'][23]="L'utente selezionato non ha un indirizzo e-mail valido. La richiesta è stata creata, ma l'e-mail non è stata inviata."; 
$LANG['validation'][26]="Richiesta di convalida"; 
$LANG['validation'][27]="E' stata inviata una richiesta di convalida"; 
$LANG['validation'][28]="Stato della richiesta di convalida"; 
$LANG['validation'][29]="Se non sei d'accordo, devi specificare la motivazione"; 
$LANG['validation'][30]="Elimina la richiesta di convalida a"; 
$LANG['validation'][31]="Aggiorna la richiesta di convalida a"; 
$LANG['validation'][32]="E' stata data una risposta ad una richiesta di convalida"; 
$LANG['validation'][33]="Chiamate in attesa della tua approvazione"; 
?>